@@ -5,18 +5,15 @@
 
 try:
     from setup_win_common import get_definitions
-except:
+except ImportError:
     from buildconfig.setup_win_common import get_definitions
 
 import os, sys
 import re
+import logging
 from glob import glob
 from distutils.sysconfig import get_python_inc
 
-try:
-    raw_input
-except NameError:
-    raw_input = input
 
 def get_ptr_size():
     return 64 if sys.maxsize > 2**32 else 32
@@ -49,7 +46,7 @@ class Dependency(object):
         self.lib_dir = None
         self.find_header = find_header
         if not find_lib and libs:
-            self.find_lib = "%s\.(a|lib)" % re.escape(libs[0])
+            self.find_lib = r"%s\.(a|lib)" % re.escape(libs[0])
         else:
             self.find_lib = find_lib
         self.libs = libs
@@ -95,21 +92,16 @@ class Dependency(object):
             if print_result:
                 print ("Path for %s: %s" % (self.name, self.path))
         else:
-            print ("Select path for %s:" % self.name)
-            for i in range(len(self.paths)):
-                print ("  %i=%s" % (i + 1, self.paths[i]))
-            print ("  %i = <Nothing>" % 0)
-            choice = raw_input("Select 0-%i (1=default):" % len(self.paths))
-            if not choice: choice = 1
-            else: choice = int(choice)
-            if(choice):
-                self.path = self.paths[choice-1]
+            logging.warning("Multiple paths to choose from:%s", self.paths)
+            self.path = self.paths[0]
+            if print_result:
+                print ("Path for %s: %s" % (self.name, self.path))
         return True
 
     def matchfile(self, path, match):
         try:
             entries = os.listdir(path)
-        except:
+        except OSError:
             pass
         else:
             for e in entries:
@@ -201,7 +193,7 @@ class DependencyPython(object):
         if self.found and self.header:
             fullpath = os.path.join(get_python_inc(0), self.header)
             if not os.path.isfile(fullpath):
-                found = 0
+                self.found = False
             else:
                 self.inc_dir = os.path.split(fullpath)[0]
         if self.found:
@@ -240,7 +232,6 @@ class DependencyDLL(Dependency):
                 print ('Too bad that is a requirement! Hand-fix the "Setup"')
 
     def check_roots(self):
-        parent = os.path.abspath('..')
         for p in self.huntpaths:
             if self.hunt_dll(self.lib_hunt, p):
                 return True
@@ -251,7 +242,7 @@ class DependencyDLL(Dependency):
             path = os.path.join(root, dir)
             try:
                 entries = os.listdir(path)
-            except:
+            except OSError:
                 pass
             else:
                 for e in entries:
@@ -382,57 +373,29 @@ def _add_sdl2_dll_deps(DEPS):
     DEPS.add_dll(r'(z|zlib1)\.dll$', 'z', ['zlib-[1-9].*'])
     DEPS.add_dll(r'(lib)?webp[-0-9]*\.dll$', 'webp', ['*webp-[0-9]*'])
 
-def setup(sdl2):
+def setup():
     DEPS = DependencyGroup()
 
-    if not sdl2:
-        DEPS.add('SDL', 'SDL', ['SDL-[1-9].*'], r'(lib){0,1}SDL\.dll$', required=1,
-                 find_header='SDL\.h')
-        DEPS.add('FONT', 'SDL_ttf', ['SDL_ttf-[2-9].*'], r'(lib){0,1}SDL_ttf\.dll$', ['SDL', 'z'],
-                 find_header='SDL_ttf\.h')
-        DEPS.add('IMAGE', 'SDL_image', ['SDL_image-[1-9].*'], r'(lib){0,1}SDL_image\.dll$',
-                 ['SDL', 'jpeg', 'png', 'tiff'], 0, find_header='SDL_image\.h'),
-        DEPS.add('MIXER', 'SDL_mixer', ['SDL_mixer-[1-9].*'], r'(lib){0,1}SDL_mixer\.dll$',
-                 ['SDL', 'vorbisfile'], find_header='SDL_mixer\.h')
-        DEPS.add('PNG', 'png', ['libpng-[1-9].*'], r'(png|libpng)[-0-9]*\.dll$', ['z'])
-        DEPS.add('JPEG', 'jpeg', ['jpeg-[6-9]*'], r'(lib){0,1}jpeg[-0-9]*\.dll$')
-        DEPS.add('PORTMIDI', 'portmidi', ['portmidi'], r'portmidi\.dll$', find_header='portmidi\.h')
-        #DEPS.add('PORTTIME', 'porttime', ['porttime'], r'porttime\.dll$')
-        DEPS.add_dummy('PORTTIME')
-        DEPS.add('FREETYPE', 'freetype', ['freetype-[1-9].*'], r'(lib){0,1}freetype[-0-9]*\.dll$',
-                 find_header='ft2build\.h', find_lib='(lib)?freetype[-0-9]*\.lib')
-        DEPS.configure()
-        DEPS.add_dll(r'(lib){0,1}tiff[-0-9]*\.dll$', 'tiff', ['tiff-[3-9].*'], ['jpeg', 'z'])
-        DEPS.add_dll(r'(z|zlib1)\.dll$', 'z', ['zlib-[1-9].*'])
-        DEPS.add_dll(r'(libvorbis-0|vorbis)\.dll$', 'vorbis', ['libvorbis-[1-9].*'],
-                     ['ogg'])
-        DEPS.add_dll(r'(libvorbisfile-3|vorbisfile)\.dll$', 'vorbisfile',
-                     link_lib='vorbis', libs=['vorbis'])
-        DEPS.add_dll(r'(libogg-0|ogg)\.dll$', 'ogg', ['libogg-[1-9].*'])
-        for d in get_definitions():
-            DEPS.add_win(d.name, d.value)
-        DEPS.configure()
-    else:
-        DEPS.add('SDL', 'SDL2', ['SDL2-[1-9].*'], r'(lib){0,1}SDL2\.dll$', required=1)
-        DEPS.add('PORTMIDI', 'portmidi', ['portmidi'], r'portmidi\.dll$', find_header='portmidi\.h')
-        #DEPS.add('PORTTIME', 'porttime', ['porttime'], r'porttime\.dll$')
-        DEPS.add_dummy('PORTTIME')
-        DEPS.add('MIXER', 'SDL2_mixer', ['SDL2_mixer-[1-9].*'], r'(lib){0,1}SDL2_mixer\.dll$',
-                 ['SDL', 'vorbisfile'])
-        DEPS.add('PNG', 'png', ['SDL2_image-[2-9].*', 'libpng-[1-9].*'], r'(png|libpng)[-0-9]*\.dll$', ['z'],
-                 find_header='png\.h', find_lib='(lib)?png1[-0-9]*\.lib')
-        DEPS.add('JPEG', 'jpeg', ['SDL2_image-[2-9].*', 'jpeg-9*'], r'(lib){0,1}jpeg-9\.dll$',
-                 find_header='jpeglib\.h', find_lib='(lib)?jpeg-9\.lib')
-        DEPS.add('IMAGE', 'SDL2_image', ['SDL2_image-[1-9].*'], r'(lib){0,1}SDL2_image\.dll$',
-                 ['SDL', 'jpeg', 'png', 'tiff'], 0)
-        DEPS.add('FONT', 'SDL2_ttf', ['SDL2_ttf-[2-9].*'], r'(lib){0,1}SDL2_ttf\.dll$', ['SDL', 'z', 'freetype'])
-        DEPS.add('FREETYPE', 'freetype', ['freetype-[1-9].*'], r'(lib){0,1}freetype[-0-9]*\.dll$',
-                 find_header='ft2build\.h', find_lib='(lib)?freetype[-0-9]*\.lib')
-        DEPS.configure()
-        _add_sdl2_dll_deps(DEPS)
-        for d in get_definitions():
-            DEPS.add_win(d.name, d.value)
-        DEPS.configure()
+    DEPS.add('SDL', 'SDL2', ['SDL2-[1-9].*'], r'(lib){0,1}SDL2\.dll$', required=1)
+    DEPS.add('PORTMIDI', 'portmidi', ['portmidi'], r'portmidi\.dll$', find_header=r'portmidi\.h')
+    #DEPS.add('PORTTIME', 'porttime', ['porttime'], r'porttime\.dll$')
+    DEPS.add_dummy('PORTTIME')
+    DEPS.add('MIXER', 'SDL2_mixer', ['SDL2_mixer-[1-9].*'], r'(lib){0,1}SDL2_mixer\.dll$',
+             ['SDL', 'vorbisfile'])
+    DEPS.add('PNG', 'png', ['SDL2_image-[2-9].*', 'libpng-[1-9].*'], r'(png|libpng)[-0-9]*\.dll$', ['z'],
+             find_header=r'png\.h', find_lib=r'(lib)?png1[-0-9]*\.lib')
+    DEPS.add('JPEG', 'jpeg', ['SDL2_image-[2-9].*', 'jpeg-9*'], r'(lib){0,1}jpeg-9\.dll$',
+             find_header=r'jpeglib\.h', find_lib=r'(lib)?jpeg-9\.lib')
+    DEPS.add('IMAGE', 'SDL2_image', ['SDL2_image-[1-9].*'], r'(lib){0,1}SDL2_image\.dll$',
+             ['SDL', 'jpeg', 'png', 'tiff'], 0)
+    DEPS.add('FONT', 'SDL2_ttf', ['SDL2_ttf-[2-9].*'], r'(lib){0,1}SDL2_ttf\.dll$', ['SDL', 'z', 'freetype'])
+    DEPS.add('FREETYPE', 'freetype', ['freetype-[1-9].*'], r'(lib){0,1}freetype[-0-9]*\.dll$',
+             find_header=r'ft2build\.h', find_lib=r'(lib)?freetype[-0-9]*\.lib')
+    DEPS.configure()
+    _add_sdl2_dll_deps(DEPS)
+    for d in get_definitions():
+        DEPS.add_win(d.name, d.value)
+    DEPS.configure()
 
     return list(DEPS)
 
@@ -453,14 +416,14 @@ def setup_prebuilt_sdl2(prebuilt_dir):
                         ['SDL', 'jpeg', 'png', 'tiff'], 0)
     mixerDep = DEPS.add('MIXER', 'SDL2_mixer', ['SDL2_mixer-[1-9].*'], r'(lib){0,1}SDL2_mixer\.dll$',
                         ['SDL', 'vorbisfile'])
-    DEPS.add('PORTMIDI', 'portmidi', ['portmidi'], r'portmidi\.dll$', find_header='portmidi\.h')
+    DEPS.add('PORTMIDI', 'portmidi', ['portmidi'], r'portmidi\.dll$', find_header=r'portmidi\.h')
     #DEPS.add('PORTTIME', 'porttime', ['porttime'], r'porttime\.dll$')
     DEPS.add_dummy('PORTTIME')
     DEPS.configure()
 
     # force use of the correct freetype DLL
     ftDep = DEPS.add('FREETYPE', 'freetype', ['SDL2_ttf-[2-9].*', 'freetype-[1-9].*'], r'(lib)?freetype[-0-9]*\.dll$',
-                     find_header='ft2build\.h', find_lib='libfreetype[-0-9]*\.lib')
+                     find_header=r'ft2build\.h', find_lib=r'libfreetype[-0-9]*\.lib')
     ftDep.path = fontDep.path
     ftDep.inc_dir = [
         os.path.join(prebuilt_dir, 'include').replace('\\', '/')
@@ -469,12 +432,12 @@ def setup_prebuilt_sdl2(prebuilt_dir):
     ftDep.found = True
 
     png = DEPS.add('PNG', 'png', ['SDL2_image-[2-9].*', 'libpng-[1-9].*'], r'(png|libpng)[-0-9]*\.dll$', ['z'],
-                   find_header='png\.h', find_lib='(lib)?png1[-0-9]*\.lib')
+                   find_header=r'png\.h', find_lib=r'(lib)?png1[-0-9]*\.lib')
     png.path = imageDep.path
     png.inc_dir = [os.path.join(prebuilt_dir, 'include').replace('\\', '/')]
     png.found = True
     jpeg = DEPS.add('JPEG', 'jpeg', ['SDL2_image-[2-9].*', 'jpeg-9*'], r'(lib){0,1}jpeg-9\.dll$',
-                   find_header='jpeglib\.h', find_lib='(lib)?jpeg-9\.lib')
+                   find_header=r'jpeglib\.h', find_lib=r'(lib)?jpeg-9\.lib')
     jpeg.path = imageDep.path
     jpeg.inc_dir = [os.path.join(prebuilt_dir, 'include').replace('\\', '/')]
     jpeg.found = True
@@ -508,48 +471,7 @@ def setup_prebuilt_sdl2(prebuilt_dir):
     DEPS.configure()
     return list(DEPS)
 
-def setup_prebuilt_sdl1(prebuilt_dir):
-    setup_ = open('Setup', 'w')
-    is_pypy = '__pypy__' in sys.builtin_module_names
-    import platform
-    is_python3 = platform.python_version().startswith('3')
-
-    try:
-        try:
-            setup_win_in = open(os.path.join(prebuilt_dir, 'Setup_Win.in'))
-        except IOError:
-            raise IOError("%s missing required Setup_Win.in" % prebuilt_dir)
-
-        # Copy Setup.in to Setup, replacing the BeginConfig/EndConfig
-        # block with prebuilt\Setup_Win.in .
-        setup_in = open(os.path.join('buildconfig', 'Setup.SDL1.in'))
-        try:
-            do_copy = True
-            for line in setup_in:
-                if line.startswith('#--StartConfig'):
-                    do_copy = False
-                    setup_.write(setup_win_in.read())
-                    try:
-                        setup_win_common_in = open(os.path.join('buildconfig', 'Setup_Win_Common.in'))
-                    except:
-                        pass
-                    else:
-                        try:
-                            setup_.write(setup_win_common_in.read())
-                        finally:
-                            setup_win_common_in.close()
-                elif line.startswith('#--EndConfig'):
-                    do_copy = True
-                elif do_copy:
-                    setup_.write(line)
-        finally:
-            setup_in.close()
-    finally:
-        setup_.close()
-
-    print("Wrote to \"Setup\".")
-
-def main(sdl2=False):
+def main():
     machine_type = get_machine_type()
     prebuilt_dir = 'prebuilt-%s' % machine_type
     use_prebuilt = '-prebuilt' in sys.argv
@@ -566,7 +488,6 @@ def main(sdl2=False):
     download_kwargs = {
         'x86': False,
         'x64': False,
-        'sdl2': sdl2,
     }
     download_kwargs[machine_type] = True
 
@@ -583,17 +504,14 @@ def main(sdl2=False):
             if 'PYGAME_USE_PREBUILT' in os.environ:
                 use_prebuilt = os.environ['PYGAME_USE_PREBUILT'] == '1'
             else:
-                reply = raw_input('\nUse the SDL libraries in "%s"? [Y/n]' % prebuilt_dir)
-                use_prebuilt = (not reply) or reply[0].lower() != 'n'
+                logging.warning('Using the SDL libraries in "%s".' % prebuilt_dir)
+                use_prebuilt = True
 
         if use_prebuilt:
-            if sdl2:
-                return setup_prebuilt_sdl2(prebuilt_dir)
-            setup_prebuilt_sdl1(prebuilt_dir)
-            raise SystemExit()
+            return setup_prebuilt_sdl2(prebuilt_dir)
     else:
         print ("Note: cannot find directory \"%s\"; do not use prebuilts." % prebuilt_dir)
-    return setup(sdl2)
+    return setup()
 
 if __name__ == '__main__':
     print ("""This is the configuration subscript for Windows.
