@@ -35,15 +35,13 @@
  */
 static const Scale_t FACE_SIZE_NONE = {0, 0};
 
-#if PY3
 static int
 _ft_traverse(PyObject *, visitproc, void *);
 static int
 _ft_clear(PyObject *);
-#endif
 
 static PyObject *
-_ft_quit(PyObject *, PyObject *);
+_ft_quit(PyObject *);
 static PyObject *
 _ft_init(PyObject *, PyObject *, PyObject *);
 static PyObject *
@@ -53,9 +51,7 @@ _ft_get_error(PyObject *, PyObject *);
 static PyObject *
 _ft_get_init(PyObject *, PyObject *);
 static PyObject *
-_ft_autoinit(PyObject *, PyObject *);
-static void
-_ft_autoquit(void);
+_ft_autoinit(PyObject *);
 static PyObject *
 _ft_get_cache_size(PyObject *, PyObject *);
 static PyObject *
@@ -142,6 +138,10 @@ static PyObject *
 _ftfont_getfgcolor(pgFontObject *, void *);
 static int
 _ftfont_setfgcolor(pgFontObject *, PyObject *, void *);
+static PyObject *
+_ftfont_getbgcolor(pgFontObject *, void *);
+static int
+_ftfont_setbgcolor(pgFontObject *, PyObject *, void *);
 
 static PyObject *
 _ftfont_getresolution(pgFontObject *, void *);
@@ -236,7 +236,6 @@ load_font_res(const char *filename)
         goto font_resource_end;
     }
 
-#if PY3
     tmp = PyObject_GetAttrString(result, "name");
     if (tmp) {
         PyObject *closeret;
@@ -254,25 +253,6 @@ load_font_res(const char *filename)
     else {
         PyErr_Clear();
     }
-#else
-    if (PyFile_Check(result)) {
-        PyObject *closeret;
-
-        tmp = PyFile_Name(result);
-        Py_INCREF(tmp);
-
-        if (!(closeret = PyObject_CallMethod(result, "close", NULL))) {
-            Py_DECREF(result);
-            Py_DECREF(tmp);
-            result = NULL;
-            goto font_resource_end;
-        }
-        Py_DECREF(closeret);
-
-        Py_DECREF(result);
-        result = tmp;
-    }
-#endif
 
 font_resource_end:
     Py_XDECREF(pkgdatamodule);
@@ -289,7 +269,7 @@ parse_dest(PyObject *dest, int *x, int *y)
     int i, j;
 
     if (!PySequence_Check(dest) || /* conditional and */
-        !PySequence_Size(dest) > 1) {
+        !(PySequence_Size(dest) > 1)) {
         PyErr_Format(PyExc_TypeError,
                      "Expected length 2 sequence for dest argument:"
                      " got type %.1024s",
@@ -314,17 +294,14 @@ parse_dest(PyObject *dest, int *x, int *y)
         Py_DECREF(oj);
         return -1;
     }
-    i = PyInt_AsLong(oi);
-    Py_DECREF(oi);
-    if (i == -1 && PyErr_Occurred()) {
+    if (!pg_IntFromObj(oi, &i) || !pg_IntFromObj(oj, &j)) {
+        Py_DECREF(oi);
         Py_DECREF(oj);
+        PyErr_SetString(PyExc_TypeError, "dest expects a pair of numbers");
         return -1;
     }
-    j = PyInt_AsLong(oj);
+    Py_DECREF(oi);
     Py_DECREF(oj);
-    if (j == -1 && PyErr_Occurred()) {
-        return -1;
-    }
     *x = i;
     *y = j;
     return 0;
@@ -354,11 +331,7 @@ objs_to_scale(PyObject *x, PyObject *y, Scale_t *size)
     int do_y;
 
     for (o = x, do_y = 1; o; o = (do_y--) ? y : 0) {
-        if (!PyLong_Check(o) &&
-#if PY2
-            !PyInt_Check(o) &&
-#endif
-            !PyFloat_Check(o)) {
+        if (!PyLong_Check(o) && !PyFloat_Check(o)) {
             if (y) {
                 PyErr_Format(PyExc_TypeError,
                              "expected a (float, float) tuple for size"
@@ -476,11 +449,6 @@ obj_to_rotation(PyObject *o, void *p)
     if (PyLong_Check(o)) {
         ;
     }
-#if PY2
-    else if (PyInt_Check(o)) {
-        ;
-    }
-#endif
     else {
         PyErr_Format(PyExc_TypeError, "integer rotation expected, got %s",
                      Py_TYPE(o)->tp_name);
@@ -516,25 +484,23 @@ free_string(PGFT_String *p)
  * FREETYPE MODULE METHODS TABLE
  */
 static PyMethodDef _ft_methods[] = {
-    {"__PYGAMEinit__", _ft_autoinit, METH_NOARGS,
+    {"__PYGAMEinit__", (PyCFunction)_ft_autoinit, METH_NOARGS,
      "auto initialize function for _freetype"},
     {"init", (PyCFunction)_ft_init, METH_VARARGS | METH_KEYWORDS,
      DOC_PYGAMEFREETYPEINIT},
-    {"quit", _ft_quit, METH_NOARGS, DOC_PYGAMEFREETYPEQUIT},
-    {"get_init", _ft_get_init, METH_NOARGS,
-     DOC_PYGAMEFREETYPEGETINIT},
+    {"quit", (PyCFunction)_ft_quit, METH_NOARGS, DOC_PYGAMEFREETYPEQUIT},
+    {"get_init", _ft_get_init, METH_NOARGS, DOC_PYGAMEFREETYPEGETINIT},
     {"was_init", _ft_get_init, METH_NOARGS,
      DOC_PYGAMEFREETYPEWASINIT},  // DEPRECATED
-    {"get_error", _ft_get_error, METH_NOARGS,
-     DOC_PYGAMEFREETYPEGETERROR},
+    {"get_error", _ft_get_error, METH_NOARGS, DOC_PYGAMEFREETYPEGETERROR},
     {"get_version", _ft_get_version, METH_NOARGS,
      DOC_PYGAMEFREETYPEGETVERSION},
     {"get_cache_size", _ft_get_cache_size, METH_NOARGS,
      DOC_PYGAMEFREETYPEGETCACHESIZE},
-    {"get_default_resolution", _ft_get_default_resolution,
-     METH_NOARGS, DOC_PYGAMEFREETYPEGETDEFAULTRESOLUTION},
-    {"set_default_resolution", _ft_set_default_resolution,
-     METH_VARARGS, DOC_PYGAMEFREETYPESETDEFAULTRESOLUTION},
+    {"get_default_resolution", _ft_get_default_resolution, METH_NOARGS,
+     DOC_PYGAMEFREETYPEGETDEFAULTRESOLUTION},
+    {"set_default_resolution", _ft_set_default_resolution, METH_VARARGS,
+     DOC_PYGAMEFREETYPESETDEFAULTRESOLUTION},
     {"get_default_font", _ft_get_default_font, METH_NOARGS,
      DOC_PYGAMEFREETYPEGETDEFAULTFONT},
 
@@ -620,6 +586,8 @@ static PyGetSetDef _ftfont_getsets[] = {
      DOC_FONTROTATION, 0},
     {"fgcolor", (getter)_ftfont_getfgcolor, (setter)_ftfont_setfgcolor,
      DOC_FONTFGCOLOR, 0},
+    {"bgcolor", (getter)_ftfont_getbgcolor, (setter)_ftfont_setbgcolor,
+     DOC_FONTBGCOLOR, 0},
     {"origin", (getter)_ftfont_getrender_flag, (setter)_ftfont_setrender_flag,
      DOC_FONTORIGIN, (void *)FT_RFLAG_ORIGIN},
 #if defined(PGFT_DEBUG_CACHE)
@@ -635,52 +603,52 @@ static PyGetSetDef _ftfont_getsets[] = {
 #define FULL_TYPE_NAME MODULE_NAME "." FONT_TYPE_NAME
 
 PyTypeObject pgFont_Type = {
-    TYPE_HEAD(0, 0) FULL_TYPE_NAME,           /* tp_name */
-    sizeof(pgFontObject),                     /* tp_basicsize */
-    0,                                        /* tp_itemsize */
-    (destructor)_ftfont_dealloc,              /* tp_dealloc */
-    0,                                        /* tp_print */
-    0,                                        /* tp_getattr */
-    0,                                        /* tp_setattr */
-    0,                                        /* tp_compare */
-    (reprfunc)_ftfont_repr,                   /* tp_repr */
-    0,                                        /* tp_as_number */
-    0,                                        /* tp_as_sequence */
-    0,                                        /* tp_as_mapping */
-    0,                                        /* tp_hash */
-    0,                                        /* tp_call */
-    0,                                        /* tp_str */
-    0,                                        /* tp_getattro */
-    0,                                        /* tp_setattro */
-    0,                                        /* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-    DOC_PYGAMEFREETYPEFONT,                   /* docstring */
-    0,                                        /* tp_traverse */
-    0,                                        /* tp_clear */
-    0,                                        /* tp_richcompare */
-    0,                                        /* tp_weaklistoffset */
-    0,                                        /* tp_iter */
-    0,                                        /* tp_iternext */
-    _ftfont_methods,                          /* tp_methods */
-    0,                                        /* tp_members */
-    _ftfont_getsets,                          /* tp_getset */
-    0,                                        /* tp_base */
-    0,                                        /* tp_dict */
-    0,                                        /* tp_descr_get */
-    0,                                        /* tp_descr_set */
-    0,                                        /* tp_dictoffset */
-    (initproc)_ftfont_init,                   /* tp_init */
-    0,                                        /* tp_alloc */
-    (newfunc)_ftfont_new,                     /* tp_new */
-    0,                                        /* tp_free */
-    0,                                        /* tp_is_gc */
-    0,                                        /* tp_bases */
-    0,                                        /* tp_mro */
-    0,                                        /* tp_cache */
-    0,                                        /* tp_subclasses */
-    0,                                        /* tp_weaklist */
-    0,                                        /* tp_del */
-    0 /* tp_version_tag */
+    PyVarObject_HEAD_INIT(0, 0) FULL_TYPE_NAME, /* tp_name */
+    sizeof(pgFontObject),                       /* tp_basicsize */
+    0,                                          /* tp_itemsize */
+    (destructor)_ftfont_dealloc,                /* tp_dealloc */
+    0,                                          /* tp_print */
+    0,                                          /* tp_getattr */
+    0,                                          /* tp_setattr */
+    0,                                          /* tp_compare */
+    (reprfunc)_ftfont_repr,                     /* tp_repr */
+    0,                                          /* tp_as_number */
+    0,                                          /* tp_as_sequence */
+    0,                                          /* tp_as_mapping */
+    0,                                          /* tp_hash */
+    0,                                          /* tp_call */
+    0,                                          /* tp_str */
+    0,                                          /* tp_getattro */
+    0,                                          /* tp_setattro */
+    0,                                          /* tp_as_buffer */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,   /* tp_flags */
+    DOC_PYGAMEFREETYPEFONT,                     /* docstring */
+    0,                                          /* tp_traverse */
+    0,                                          /* tp_clear */
+    0,                                          /* tp_richcompare */
+    0,                                          /* tp_weaklistoffset */
+    0,                                          /* tp_iter */
+    0,                                          /* tp_iternext */
+    _ftfont_methods,                            /* tp_methods */
+    0,                                          /* tp_members */
+    _ftfont_getsets,                            /* tp_getset */
+    0,                                          /* tp_base */
+    0,                                          /* tp_dict */
+    0,                                          /* tp_descr_get */
+    0,                                          /* tp_descr_set */
+    0,                                          /* tp_dictoffset */
+    (initproc)_ftfont_init,                     /* tp_init */
+    0,                                          /* tp_alloc */
+    (newfunc)_ftfont_new,                       /* tp_new */
+    0,                                          /* tp_free */
+    0,                                          /* tp_is_gc */
+    0,                                          /* tp_bases */
+    0,                                          /* tp_mro */
+    0,                                          /* tp_cache */
+    0,                                          /* tp_subclasses */
+    0,                                          /* tp_weaklist */
+    0,                                          /* tp_del */
+    0                                           /* tp_version_tag */
 };
 
 #undef FULL_TYPE_NAME
@@ -715,6 +683,11 @@ _ftfont_new(PyTypeObject *subtype, PyObject *args, PyObject *kwds)
         obj->fgcolor[1] = 0;
         obj->fgcolor[2] = 0;
         obj->fgcolor[3] = 255;
+        obj->is_bg_col_set = 0;
+        obj->bgcolor[0] = 0; /* rgba transparent black */
+        obj->bgcolor[1] = 0;
+        obj->bgcolor[2] = 0;
+        obj->bgcolor[3] = 0;
     }
     return (PyObject *)obj;
 }
@@ -722,15 +695,11 @@ _ftfont_new(PyTypeObject *subtype, PyObject *args, PyObject *kwds)
 static void
 _ftfont_dealloc(pgFontObject *self)
 {
-#ifdef HAVE_PYGAME_SDL_RWOPS
     SDL_RWops *src = _PGFT_GetRWops(self);
-#endif
     _PGFT_UnloadFont(self->freetype, self);
-#ifdef HAVE_PYGAME_SDL_RWOPS
     if (src) {
         pgRWops_ReleaseObject(src);
     }
-#endif
     _PGFT_Quit(self->freetype);
 
     Py_XDECREF(self->path);
@@ -746,7 +715,7 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
     PyObject *file, *original_file;
     long font_index = 0;
     Scale_t face_size = self->face_size;
-    int ucs4 = self->render_flags & FT_RFLAG_UCS4 ? 1 : 0;
+    int ucs4 = (self->render_flags & FT_RFLAG_UCS4) ? 1 : 0;
     unsigned resolution = 0;
     long size = 0;
     long height = 0;
@@ -799,36 +768,37 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
         }
     }
 
-#if !defined(WIN32) || !defined(HAVE_PYGAME_SDL_RWOPS)
+#if !defined(WIN32)
     file = pg_EncodeString(file, "UTF-8", NULL, NULL);
     if (!file) {
         goto end;
     }
-    if (Bytes_Check(file)) {
+    if (PyBytes_Check(file)) {
         if (PyUnicode_Check(original_file)) {
             /* Make sure to save a pure Unicode object to prevent possible
              * cycles from a derived class. This means no tp_traverse or
              * tp_clear for the PyFreetypeFont type.
              */
-            self->path = Object_Unicode(original_file);
+            self->path = PyObject_Str(original_file);
         }
         else {
-            self->path = PyUnicode_FromEncodedObject(
-                file, "UTF-8", NULL);
+            self->path = PyUnicode_FromEncodedObject(file, "UTF-8", NULL);
         }
         if (!self->path) {
             goto end;
         }
 
-        if (_PGFT_TryLoadFont_Filename(ft, self, Bytes_AS_STRING(file),
+        if (_PGFT_TryLoadFont_Filename(ft, self, PyBytes_AS_STRING(file),
                                        font_index)) {
             goto end;
         }
-    } else {
+    }
+    else {
         PyObject *str = 0;
         PyObject *path = 0;
-        if (!PG_CHECK_THREADS())
-            goto end;
+#ifndef WITH_THREAD
+        goto end;
+#endif
         source = pgRWops_FromFileObject(original_file);
         if (!source) {
             goto end;
@@ -837,8 +807,8 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
         path = PyObject_GetAttrString(original_file, "name");
         if (!path) {
             PyErr_Clear();
-            str = Bytes_FromFormat("<%s instance at %p>",
-                                   Py_TYPE(file)->tp_name, (void *)file);
+            str = PyBytes_FromFormat("<%s instance at %p>",
+                                     Py_TYPE(file)->tp_name, (void *)file);
             if (str) {
                 self->path =
                     PyUnicode_FromEncodedObject(str, "ascii", "strict");
@@ -850,14 +820,13 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
              * cycles from a derived class. This means no tp_traverse or
              * tp_clear for the PyFreetypeFont type.
              */
-            self->path = Object_Unicode(path);
+            self->path = PyObject_Str(path);
         }
-        else if (Bytes_Check(path)) {
-            self->path = PyUnicode_FromEncodedObject(
-                path, "UTF-8", NULL);
+        else if (PyBytes_Check(path)) {
+            self->path = PyUnicode_FromEncodedObject(path, "UTF-8", NULL);
         }
         else {
-            self->path = Object_Unicode(path);
+            self->path = PyObject_Str(path);
         }
         Py_XDECREF(path);
         if (!self->path) {
@@ -868,7 +837,7 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
             goto end;
         }
     }
-#else /* WIN32 && HAVE_PYGAME_SDL_RWOPS */
+#else  /* WIN32 */
     /* FT uses fopen(); as a workaround, always use RWops */
     if (file == original_file)
         Py_INCREF(file);
@@ -877,20 +846,22 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
     source = pgRWops_FromObject(file);
     if (!source) {
         goto end;
-    } else {
+    }
+    else {
         PyObject *path = 0;
 
         if (pgRWops_IsFileObject(source)) {
             path = PyObject_GetAttrString(file, "name");
-        } else {
+        }
+        else {
             Py_INCREF(file);
             path = file;
         }
         if (!path) {
             PyObject *str;
             PyErr_Clear();
-            str = Bytes_FromFormat("<%s instance at %p>",
-                                   Py_TYPE(file)->tp_name, (void *)file);
+            str = PyBytes_FromFormat("<%s instance at %p>",
+                                     Py_TYPE(file)->tp_name, (void *)file);
             if (str) {
                 self->path =
                     PyUnicode_FromEncodedObject(str, "ascii", "strict");
@@ -902,14 +873,13 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
              * cycles from a derived class. This means no tp_traverse or
              * tp_clear for the PyFreetypeFont type.
              */
-            self->path = Object_Unicode(path);
+            self->path = PyObject_Str(path);
         }
-        else if (Bytes_Check(path)) {
-            self->path = PyUnicode_FromEncodedObject(
-                path, "UTF-8", NULL);
+        else if (PyBytes_Check(path)) {
+            self->path = PyUnicode_FromEncodedObject(path, "UTF-8", NULL);
         }
         else {
-            self->path = Object_Unicode(path);
+            self->path = PyObject_Str(path);
         }
         Py_XDECREF(path);
         if (!self->path) {
@@ -920,7 +890,7 @@ _ftfont_init(pgFontObject *self, PyObject *args, PyObject *kwds)
             goto end;
         }
     }
-#endif /* WIN32 && HAVE_PYGAME_SDL_RWOPS */
+#endif /* WIN32 */
 
     if (!self->is_scalable && self->face_size.x == 0) {
         if (_PGFT_Font_GetAvailableSize(ft, self, 0, &size, &height, &width,
@@ -951,22 +921,10 @@ static PyObject *
 _ftfont_repr(pgFontObject *self)
 {
     if (pgFont_IS_ALIVE(self)) {
-#if PY3
         return PyUnicode_FromFormat("Font('%.1024U')", self->path);
-#else
-        PyObject *str = PyUnicode_AsEncodedString(
-            self->path, "raw_unicode_escape", "replace");
-        PyObject *rval = 0;
-
-        if (str) {
-            rval = PyString_FromFormat("Font('%.1024s')",
-                                       PyString_AS_STRING(str));
-            Py_DECREF(str);
-        }
-        return rval;
-#endif
     }
-    return Text_FromFormat("<uninitialized Font object at %p>", (void *)self);
+    return PyUnicode_FromFormat("<uninitialized Font object at %p>",
+                                (void *)self);
 }
 
 /****************************************************
@@ -977,15 +935,15 @@ _ftfont_repr(pgFontObject *self)
 static PyObject *
 _ftfont_getstyle_flag(pgFontObject *self, void *closure)
 {
-    const int style_flag = (int)closure;
+    const long style_flag = (long)closure;
 
-    return PyBool_FromLong(self->style & style_flag);
+    return PyBool_FromLong(self->style & (FT_UInt16)style_flag);
 }
 
 static int
 _ftfont_setstyle_flag(pgFontObject *self, PyObject *value, void *closure)
 {
-    const int style_flag = (int)closure;
+    const long style_flag = (long)closure;
 
     if (!PyBool_Check(value)) {
         PyErr_SetString(PyExc_TypeError, "The style value must be a boolean");
@@ -1017,7 +975,7 @@ _ftfont_setstyle_flag(pgFontObject *self, PyObject *value, void *closure)
 static PyObject *
 _ftfont_getstyle(pgFontObject *self, void *closure)
 {
-    return PyInt_FromLong(self->style);
+    return PyLong_FromLong(self->style);
 }
 
 static int
@@ -1025,14 +983,14 @@ _ftfont_setstyle(pgFontObject *self, PyObject *value, void *closure)
 {
     FT_UInt32 style;
 
-    if (!PyInt_Check(value)) {
+    if (!PyLong_Check(value)) {
         PyErr_SetString(PyExc_TypeError,
                         "The style value must be an integer"
                         " from the FT constants module");
         return -1;
     }
 
-    style = (FT_UInt32)PyInt_AsLong(value);
+    style = (FT_UInt32)PyLong_AsLong(value);
 
     if (style == FT_STYLE_DEFAULT) {
         /* The Font object's style property is the Font's default style,
@@ -1103,6 +1061,8 @@ _ftfont_setsize(pgFontObject *self, PyObject *value, void *closure)
 {
     Scale_t face_size;
 
+    DEL_ATTR_NOT_SUPPORTED_CHECK("size", value);
+
     if (!obj_to_scale(value, &face_size))
         goto error;
     self->face_size = face_size;
@@ -1122,9 +1082,13 @@ static int
 _ftfont_setunderlineadjustment(pgFontObject *self, PyObject *value,
                                void *closure)
 {
-    PyObject *adjustmentobj = PyNumber_Float(value);
+    PyObject *adjustmentobj;
     double adjustment;
 
+    DEL_ATTR_NOT_SUPPORTED_CHECK("underline_adjustment", value);
+
+    adjustmentobj = PyNumber_Float(value);
+
     if (!adjustmentobj) {
         return -1;
     }
@@ -1156,17 +1120,15 @@ _ftfont_getfontmetric(pgFontObject *self, void *closure)
     if (!height && PyErr_Occurred()) {
         return 0;
     }
-    return PyInt_FromLong(height);
+    return PyLong_FromLong(height);
 }
 
 static PyObject *
 _ftfont_getname(pgFontObject *self, void *closure)
 {
-    const char *name;
-
     if (pgFont_IS_ALIVE(self)) {
-        name = _PGFT_Font_GetName(self->freetype, self);
-        return name ? Text_FromUTF8(name) : 0;
+        const char *name = _PGFT_Font_GetName(self->freetype, self);
+        return name ? PyUnicode_FromString(name) : 0;
     }
     return PyObject_Repr((PyObject *)self);
 }
@@ -1209,22 +1171,25 @@ _ftfont_getfixedsizes(pgFontObject *self, void *closure)
 
     ASSERT_SELF_IS_ALIVE(self);
     num_fixed_sizes = _PGFT_Font_NumFixedSizes(self->freetype, self);
-    return num_fixed_sizes >= 0 ? PyInt_FromLong(num_fixed_sizes) : 0;
+    return num_fixed_sizes >= 0 ? PyLong_FromLong(num_fixed_sizes) : 0;
 }
 
 /** Generic render flag attributes */
 static PyObject *
 _ftfont_getrender_flag(pgFontObject *self, void *closure)
 {
-    const int render_flag = (int)closure;
+    const long render_flag = (long)closure;
 
-    return PyBool_FromLong(self->render_flags & render_flag);
+    return PyBool_FromLong(self->render_flags & (FT_UInt16)render_flag);
 }
 
 static int
 _ftfont_setrender_flag(pgFontObject *self, PyObject *value, void *closure)
 {
-    const int render_flag = (int)closure;
+    const long render_flag = (long)closure;
+
+    /* Generic setter; We do not know the name of the attribute */
+    DEL_ATTR_NOT_SUPPORTED_CHECK(NULL, value);
 
     if (!PyBool_Check(value)) {
         PyErr_SetString(PyExc_TypeError, "The style value must be a boolean");
@@ -1258,6 +1223,8 @@ _ftfont_getrotation(pgFontObject *self, void *closure)
 static int
 _ftfont_setrotation(pgFontObject *self, PyObject *value, void *closure)
 {
+    DEL_ATTR_NOT_SUPPORTED_CHECK("rotation", value);
+
     if (!self->is_scalable) {
         if (pgFont_IS_ALIVE(self)) {
             PyErr_SetString(PyExc_AttributeError,
@@ -1282,6 +1249,8 @@ _ftfont_getfgcolor(pgFontObject *self, void *closure)
 static int
 _ftfont_setfgcolor(pgFontObject *self, PyObject *value, void *closure)
 {
+    DEL_ATTR_NOT_SUPPORTED_CHECK("fgcolor", value);
+
     if (!pg_RGBAFromObj(value, self->fgcolor)) {
         PyErr_Format(PyExc_AttributeError,
                      "unable to convert %128s object to a color",
@@ -1291,6 +1260,29 @@ _ftfont_setfgcolor(pgFontObject *self, PyObject *value, void *closure)
     return 0;
 }
 
+static PyObject *
+_ftfont_getbgcolor(pgFontObject *self, void *closure)
+{
+    return pgColor_New(self->bgcolor);
+}
+
+static int
+_ftfont_setbgcolor(pgFontObject *self, PyObject *value, void *closure)
+{
+    DEL_ATTR_NOT_SUPPORTED_CHECK("bgcolor", value);
+
+    if (!pg_RGBAFromObj(value, self->bgcolor)) {
+        PyErr_Format(PyExc_AttributeError,
+                     "unable to convert %128s object to a color",
+                     Py_TYPE(value)->tp_name);
+        return -1;
+    }
+    else {
+        self->is_bg_col_set = 1;
+    }
+    return 0;
+}
+
 /** testing and debugging */
 #if defined(PGFT_DEBUG_CACHE)
 static PyObject *
@@ -1471,9 +1463,9 @@ _ftfont_getsizedascender(pgFontObject *self, PyObject *args)
 
     if (face_size.x == 0) {
         if (self->face_size.x == 0) {
-            RAISE(PyExc_ValueError,
-                  "No font point size specified"
-                  " and no default font size in typefont");
+            PyErr_SetString(PyExc_ValueError,
+                            "No font point size specified"
+                            " and no default font size in typefont");
             return 0;
         }
 
@@ -1483,7 +1475,7 @@ _ftfont_getsizedascender(pgFontObject *self, PyObject *args)
     if (!value && PyErr_Occurred()) {
         return 0;
     }
-    return PyInt_FromLong(value);
+    return PyLong_FromLong(value);
 }
 
 static PyObject *
@@ -1498,9 +1490,9 @@ _ftfont_getsizeddescender(pgFontObject *self, PyObject *args)
 
     if (face_size.x == 0) {
         if (self->face_size.x == 0) {
-            RAISE(PyExc_ValueError,
-                  "No font point size specified"
-                  " and no default font size in typefont");
+            PyErr_SetString(PyExc_ValueError,
+                            "No font point size specified"
+                            " and no default font size in typefont");
             return 0;
         }
 
@@ -1511,7 +1503,7 @@ _ftfont_getsizeddescender(pgFontObject *self, PyObject *args)
     if (!value && PyErr_Occurred()) {
         return 0;
     }
-    return PyInt_FromLong(value);
+    return PyLong_FromLong(value);
 }
 
 static PyObject *
@@ -1526,9 +1518,9 @@ _ftfont_getsizedheight(pgFontObject *self, PyObject *args)
 
     if (face_size.x == 0) {
         if (self->face_size.x == 0) {
-            RAISE(PyExc_ValueError,
-                  "No font point size specified"
-                  " and no default font size in typeface");
+            PyErr_SetString(PyExc_ValueError,
+                            "No font point size specified"
+                            " and no default font size in typeface");
             return 0;
         }
 
@@ -1538,7 +1530,7 @@ _ftfont_getsizedheight(pgFontObject *self, PyObject *args)
     if (!value && PyErr_Occurred()) {
         return 0;
     }
-    return PyInt_FromLong(value);
+    return PyLong_FromLong(value);
 }
 
 static PyObject *
@@ -1553,9 +1545,9 @@ _ftfont_getsizedglyphheight(pgFontObject *self, PyObject *args)
 
     if (face_size.x == 0) {
         if (self->face_size.x == 0) {
-            RAISE(PyExc_ValueError,
-                  "No font point size specified"
-                  " and no default font size in typeface");
+            PyErr_SetString(PyExc_ValueError,
+                            "No font point size specified"
+                            " and no default font size in typeface");
             return 0;
         }
 
@@ -1566,14 +1558,14 @@ _ftfont_getsizedglyphheight(pgFontObject *self, PyObject *args)
     if (!value && PyErr_Occurred()) {
         return 0;
     }
-    return PyInt_FromLong(value);
+    return PyLong_FromLong(value);
 }
 
 static PyObject *
 _ftfont_getsizes(pgFontObject *self)
 {
     int nsizes;
-    unsigned i;
+    int i;
     int rc;
     long size = 0;
     long height = 0, width = 0;
@@ -1737,13 +1729,6 @@ error:
 static PyObject *
 _ftfont_render(pgFontObject *self, PyObject *args, PyObject *kwds)
 {
-#ifndef HAVE_PYGAME_SDL_VIDEO
-
-    PyErr_SetString(PyExc_RuntimeError,
-                    "SDL support is missing. Cannot render on surfonts");
-    return 0;
-
-#else
     /* keyword list */
     static char *kwlist[] = {"text",     "fgcolor", "bgcolor", "style",
                              "rotation", "size",    0};
@@ -1787,8 +1772,8 @@ _ftfont_render(pgFontObject *self, PyObject *args, PyObject *kwds)
     }
 
     if (fg_color_obj) {
-        if (!pg_RGBAFromColorObj(fg_color_obj, (Uint8 *)&fg_color)) {
-            PyErr_SetString(PyExc_TypeError, "fgcolor must be a Color");
+        if (!pg_RGBAFromFuzzyColorObj(fg_color_obj, (Uint8 *)&fg_color)) {
+            /* Exception already set for us */
             goto error;
         }
     }
@@ -1798,12 +1783,24 @@ _ftfont_render(pgFontObject *self, PyObject *args, PyObject *kwds)
         fg_color.b = self->fgcolor[2];
         fg_color.a = self->fgcolor[3];
     }
+
     if (bg_color_obj) {
-        if (!pg_RGBAFromColorObj(bg_color_obj, (Uint8 *)&bg_color)) {
-            PyErr_SetString(PyExc_TypeError, "bgcolor must be a Color");
+        if (!pg_RGBAFromFuzzyColorObj(bg_color_obj, (Uint8 *)&bg_color)) {
+            /* Exception already set for us */
             goto error;
         }
     }
+    else {
+        if (self->is_bg_col_set) {
+            bg_color.r = self->bgcolor[0];
+            bg_color.g = self->bgcolor[1];
+            bg_color.b = self->bgcolor[2];
+            bg_color.a = self->bgcolor[3];
+        }
+        else {
+            bg_color_obj = 0;
+        }
+    }
 
     /* Encode text */
     if (textobj != Py_None) {
@@ -1817,13 +1814,13 @@ _ftfont_render(pgFontObject *self, PyObject *args, PyObject *kwds)
                               rotation))
         goto error;
 
-    surface =
-        _PGFT_Render_NewSurface(self->freetype, self, &render, text, &fg_color,
-                                bg_color_obj ? &bg_color : 0, &r);
+    surface = _PGFT_Render_NewSurface(
+        self->freetype, self, &render, text, &fg_color,
+        (bg_color_obj || self->is_bg_col_set) ? &bg_color : 0, &r);
     if (!surface)
         goto error;
     free_string(text);
-    surface_obj = pgSurface_New(surface);
+    surface_obj = (PyObject *)pgSurface_New(surface);
     if (!surface_obj)
         goto error;
 
@@ -1849,20 +1846,11 @@ error:
     Py_XDECREF(rect_obj);
     Py_XDECREF(rtuple);
     return 0;
-
-#endif  // HAVE_PYGAME_SDL_VIDEO
 }
 
 static PyObject *
 _ftfont_render_to(pgFontObject *self, PyObject *args, PyObject *kwds)
 {
-#ifndef HAVE_PYGAME_SDL_VIDEO
-
-    PyErr_SetString(PyExc_RuntimeError,
-                    "SDL support is missing. Cannot render on surfaces");
-    return 0;
-
-#else
     /* keyword list */
     static char *kwlist[] = {"surf",  "dest",     "text", "fgcolor", "bgcolor",
                              "style", "rotation", "size", 0};
@@ -1907,8 +1895,8 @@ _ftfont_render_to(pgFontObject *self, PyObject *args, PyObject *kwds)
     if (parse_dest(dest, &xpos, &ypos))
         goto error;
     if (fg_color_obj) {
-        if (!pg_RGBAFromColorObj(fg_color_obj, (Uint8 *)&fg_color)) {
-            PyErr_SetString(PyExc_TypeError, "fgcolor must be a Color");
+        if (!pg_RGBAFromFuzzyColorObj(fg_color_obj, (Uint8 *)&fg_color)) {
+            /* Exception already set for us */
             goto error;
         }
     }
@@ -1919,11 +1907,22 @@ _ftfont_render_to(pgFontObject *self, PyObject *args, PyObject *kwds)
         fg_color.a = self->fgcolor[3];
     }
     if (bg_color_obj) {
-        if (!pg_RGBAFromColorObj(bg_color_obj, (Uint8 *)&bg_color)) {
-            PyErr_SetString(PyExc_TypeError, "bgcolor must be a Color");
+        if (!pg_RGBAFromFuzzyColorObj(bg_color_obj, (Uint8 *)&bg_color)) {
+            /* Exception already set for us */
             goto error;
         }
     }
+    else {
+        if (self->is_bg_col_set) {
+            bg_color.r = self->bgcolor[0];
+            bg_color.g = self->bgcolor[1];
+            bg_color.b = self->bgcolor[2];
+            bg_color.a = self->bgcolor[3];
+        }
+        else {
+            bg_color_obj = 0;
+        }
+    }
 
     ASSERT_SELF_IS_ALIVE(self);
 
@@ -1944,9 +1943,10 @@ _ftfont_render_to(pgFontObject *self, PyObject *args, PyObject *kwds)
         PyErr_SetString(pgExc_SDLError, "display Surface quit");
         goto error;
     }
-    if (_PGFT_Render_ExistingSurface(self->freetype, self, &render, text,
-                                     surface, xpos, ypos, &fg_color,
-                                     bg_color_obj ? &bg_color : 0, &r))
+    if (_PGFT_Render_ExistingSurface(
+            self->freetype, self, &render, text, surface, xpos, ypos,
+            &fg_color, (bg_color_obj || self->is_bg_col_set) ? &bg_color : 0,
+            &r))
         goto error;
     free_string(text);
 
@@ -1955,7 +1955,6 @@ _ftfont_render_to(pgFontObject *self, PyObject *args, PyObject *kwds)
 error:
     free_string(text);
     return 0;
-#endif  // HAVE_PYGAME_SDL_VIDEO
 }
 
 /****************************************************
@@ -2005,28 +2004,26 @@ pgFont_New(const char *filename, long font_index)
  ***************************************************************/
 
 static PyObject *
-_ft_autoinit(PyObject *self, PyObject *args)
+_ft_autoinit(PyObject *self)
 {
     int cache_size = FREETYPE_MOD_STATE(self)->cache_size;
-    FT_Error result = 1;
 
     if (!FREETYPE_MOD_STATE(self)->freetype) {
-        pg_RegisterQuit(_ft_autoquit);
-
-        if (cache_size == 0) {
+        if (cache_size == 0)
             cache_size = PGFT_DEFAULT_CACHE_SIZE;
-        }
-        if (_PGFT_Init(&(FREETYPE_MOD_STATE(self)->freetype), cache_size)) {
-            return 0;
-        }
+
+        if (_PGFT_Init(&(FREETYPE_MOD_STATE(self)->freetype), cache_size))
+            return RAISE(PyExc_RuntimeError,
+                         "Failed to initialize freetype library");
+
         FREETYPE_MOD_STATE(self)->cache_size = cache_size;
     }
 
-    return PyInt_FromLong(result);
+    Py_RETURN_NONE;
 }
 
-static void
-_ft_autoquit(void)
+static PyObject *
+_ft_quit(PyObject *self)
 {
     _FreeTypeState *state = FREETYPE_STATE;
 
@@ -2035,12 +2032,7 @@ _ft_autoquit(void)
         state->cache_size = 0;
         state->freetype = 0;
     }
-}
 
-static PyObject *
-_ft_quit(PyObject *self, PyObject *args)
-{
-    _ft_autoquit();
     Py_RETURN_NONE;
 }
 
@@ -2049,29 +2041,20 @@ _ft_init(PyObject *self, PyObject *args, PyObject *kwds)
 {
     static char *kwlist[] = {"cache_size", "resolution", 0};
 
-    PyObject *result;
     unsigned cache_size = 0;
     unsigned resolution = 0;
     _FreeTypeState *state = FREETYPE_MOD_STATE(self);
 
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "|II", kwlist, &cache_size,
                                      &resolution)) {
-        return 0;
+        return NULL;
     }
 
     if (!state->freetype) {
         state->cache_size = cache_size;
         state->resolution =
             (resolution ? (FT_UInt)resolution : PGFT_DEFAULT_RESOLUTION);
-        result = _ft_autoinit(self, NULL);
-
-        if (!result) {
-            PyErr_Clear();
-            PyErr_SetString(PyExc_RuntimeError,
-                            "Failed to initialize the FreeType2 library");
-            return 0;
-        }
-        Py_DECREF(result);
+        return _ft_autoinit(self);
     }
 
     Py_RETURN_NONE;
@@ -2084,7 +2067,7 @@ _ft_get_error(PyObject *self, PyObject *args)
     ASSERT_GRAB_FREETYPE(ft, 0);
 
     if (ft->_error_msg[0]) {
-        return Text_FromUTF8(ft->_error_msg);
+        return PyUnicode_FromString(ft->_error_msg);
     }
 
     Py_RETURN_NONE;
@@ -2136,10 +2119,9 @@ _ft_get_init(PyObject *self, PyObject *args)
 static PyObject *
 _ft_get_default_font(PyObject *self, PyObject *args)
 {
-    return Text_FromUTF8(DEFAULT_FONT_NAME);
+    return PyUnicode_FromString(DEFAULT_FONT_NAME);
 }
 
-#if PY3
 static int
 _ft_traverse(PyObject *mod, visitproc visit, void *arg)
 {
@@ -2155,27 +2137,28 @@ _ft_clear(PyObject *mod)
     }
     return 0;
 }
-#endif
 
 /****************************************************
  * FREETYPE MODULE DECLARATION
  ****************************************************/
-#if PY3
 #ifndef PYPY_VERSION
 struct PyModuleDef _freetypemodule = {
     PyModuleDef_HEAD_INIT,  MODULE_NAME, DOC_PYGAMEFREETYPE,
     sizeof(_FreeTypeState), _ft_methods, 0,
     _ft_traverse,           _ft_clear,   0};
-#else /* PYPY_VERSION */
+#else  /* PYPY_VERSION */
 _FreeTypeState _modstate;
 struct PyModuleDef _freetypemodule = {
-    PyModuleDef_HEAD_INIT,  MODULE_NAME, DOC_PYGAMEFREETYPE,
-    -1 /* PyModule_GetState() not implemented */, _ft_methods, 0,
-    _ft_traverse, _ft_clear, 0};
+    PyModuleDef_HEAD_INIT,
+    MODULE_NAME,
+    DOC_PYGAMEFREETYPE,
+    -1 /* PyModule_GetState() not implemented */,
+    _ft_methods,
+    0,
+    _ft_traverse,
+    _ft_clear,
+    0};
 #endif /* PYPY_VERSION */
-#else /* PY2 */
-_FreeTypeState _modstate;
-#endif /* PY2 */
 
 MODINIT_DEFINE(_freetype)
 {
@@ -2184,43 +2167,38 @@ MODINIT_DEFINE(_freetype)
 
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     import_pygame_surface();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     import_pygame_color();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     import_pygame_rwobject();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     import_pygame_rect();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     /* type preparation */
     if (PyType_Ready(&pgFont_Type) < 0) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
-#if PY3
     module = PyModule_Create(&_freetypemodule);
-#else
-    /* TODO: DOC */
-    module = Py_InitModule3(MODULE_NAME, _ft_methods, DOC_PYGAMEFREETYPE);
-#endif
 
     if (!module) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     FREETYPE_MOD_STATE(module)->freetype = 0;
@@ -2231,11 +2209,15 @@ MODINIT_DEFINE(_freetype)
     if (PyModule_AddObject(module, FONT_TYPE_NAME, (PyObject *)&pgFont_Type) ==
         -1) {
         Py_DECREF((PyObject *)&pgFont_Type);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
-#define DEC_CONST(x) PyModule_AddIntConstant(module, #x, (int)FT_##x)
+#define DEC_CONST(x)                                        \
+    if (PyModule_AddIntConstant(module, #x, (int)FT_##x)) { \
+        Py_DECREF(module);                                  \
+        return NULL;                                        \
+    }
 
     DEC_CONST(STYLE_NORMAL);
     DEC_CONST(STYLE_STRONG);
@@ -2258,15 +2240,15 @@ MODINIT_DEFINE(_freetype)
 
     apiobj = encapsulate_api(c_api, "freetype");
     if (!apiobj) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
     if (PyModule_AddObject(module, PYGAMEAPI_LOCAL_ENTRY, apiobj) == -1) {
         Py_DECREF(apiobj);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
-    MODINIT_RETURN(module);
+    return module;
 }
