@@ -60,12 +60,6 @@ QDGlobals pg_qd;
 #endif
 #define BUF_MY_ENDIAN '='
 
-#if PY3
-#define INT_CHECK(o) PyLong_Check(o)
-#else
-#define INT_CHECK(o) (PyInt_Check(o) || PyLong_Check(o))
-#endif
-
 /* Extended array struct */
 typedef struct pg_capsule_interface_s {
     PyArrayInterface inter;
@@ -85,24 +79,17 @@ static PyObject *pgExc_BufferError = NULL;
 static PyObject *pg_quit_functions = NULL;
 static int pg_is_init = 0;
 static int pg_sdl_was_init = 0;
-#if IS_SDLv2
 SDL_Window *pg_default_window = NULL;
-PyObject *pg_default_screen = NULL;
-#endif /* IS_SDLv2 */
+pgSurfaceObject *pg_default_screen = NULL;
+static char *pg_env_blend_alpha_SDL2 = NULL;
 
 static void
 pg_install_parachute(void);
 static void
 pg_uninstall_parachute(void);
 static void
-_pg_quit(void);
-static void
 pg_atexit_quit(void);
 static int
-pgVideo_AutoInit(void);
-static void
-pgVideo_AutoQuit(void);
-static int
 pgGetArrayStruct(PyObject *, PyObject **, PyArrayInterface **);
 static PyObject *
 pgArrayStruct_AsDict(PyArrayInterface *);
@@ -159,10 +146,8 @@ static int
 _pg_as_arrayinter_flags(Py_buffer *);
 static pgCapsuleInterface *
 _pg_new_capsuleinterface(Py_buffer *);
-#if PY3
 static void
 _pg_capsule_PyMem_Free(PyObject *);
-#endif
 static PyObject *
 _pg_shape_as_tuple(PyArrayInterface *);
 static PyObject *
@@ -177,38 +162,20 @@ static void
 _pg_release_buffer_array(Py_buffer *);
 static void
 _pg_release_buffer_generic(Py_buffer *);
-#if IS_SDLv2
 static SDL_Window *
 pg_GetDefaultWindow(void);
 static void
 pg_SetDefaultWindow(SDL_Window *);
-static PyObject *
+static pgSurfaceObject *
 pg_GetDefaultWindowSurface(void);
 static void
-pg_SetDefaultWindowSurface(PyObject *);
-#endif /* IS_SDLv2 */
+pg_SetDefaultWindowSurface(pgSurfaceObject *);
+static char *
+pg_EnvShouldBlendAlphaSDL2(void);
 
 static int
 pg_CheckSDLVersions(void) /*compare compiled to linked*/
 {
-#if IS_SDLv1
-    SDL_version compiled;
-    const SDL_version *linked;
-
-    SDL_VERSION(&compiled);
-    linked = SDL_Linked_Version();
-
-    /*only check the major and minor version numbers.
-      we will relax any differences in 'patch' version.*/
-
-    if (compiled.major != linked->major || compiled.minor != linked->minor) {
-        PyErr_Format(PyExc_RuntimeError,
-                     "SDL compiled with version %d.%d.%d, linked to %d.%d.%d",
-                     compiled.major, compiled.minor, compiled.patch,
-                     linked->major, linked->minor, linked->patch);
-        return 0;
-    }
-#else  /* IS_SDLv2 */
     SDL_version compiled;
     SDL_version linked;
 
@@ -225,7 +192,6 @@ pg_CheckSDLVersions(void) /*compare compiled to linked*/
                      linked.major, linked.minor, linked.patch);
         return 0;
     }
-#endif /* IS_SDLv2 */
 
     return 1;
 }
@@ -233,8 +199,6 @@ pg_CheckSDLVersions(void) /*compare compiled to linked*/
 void
 pg_RegisterQuit(void (*func)(void))
 {
-    PyObject *obj;
-
     if (!pg_quit_functions) {
         pg_quit_functions = PyList_New(0);
         if (!pg_quit_functions) {
@@ -242,8 +206,13 @@ pg_RegisterQuit(void (*func)(void))
         }
     }
     if (func) {
-        obj = PyCapsule_New(func, "quit", NULL);
-        PyList_Append(pg_quit_functions, obj);
+        PyObject *obj = PyCapsule_New(func, "quit", NULL);
+        if (!obj) {
+            return;
+        }
+        /* There is no difference between success and error
+           for PyList_Append in this case */
+        (void)PyList_Append(pg_quit_functions, obj);
         Py_DECREF(obj);
     }
 }
@@ -257,18 +226,92 @@ pg_register_quit(PyObject *self, PyObject *value)
             return NULL;
         }
     }
-    PyList_Append(pg_quit_functions, value);
+    if (0 != PyList_Append(pg_quit_functions, value)) {
+        return NULL; /* Exception already set */
+    }
 
     Py_RETURN_NONE;
 }
 
-static PyObject *
-pg_init(PyObject *self, PyObject *args)
+/* init pygame modules, returns 1 if successful, 0 if fail, with PyErr set*/
+static int
+pg_mod_autoinit(const char *modname)
 {
-    PyObject *allmodules, *moduleslist, *dict, *func, *result, *mod;
-    int loop, num;
+    PyObject *module, *funcobj, *temp;
+    int ret = 0;
 
-    int success = 0, fail = 0;
+    module = PyImport_ImportModule(modname);
+    if (!module)
+        return 0;
+
+    funcobj = PyObject_GetAttrString(module, "__PYGAMEinit__");
+
+    /* If we could not load __PYGAMEinit__, load init function */
+    if (!funcobj) {
+        PyErr_Clear();
+        funcobj = PyObject_GetAttrString(module, "init");
+    }
+
+    if (funcobj) {
+        temp = PyObject_CallObject(funcobj, NULL);
+        if (temp) {
+            Py_DECREF(temp);
+            ret = 1;
+        }
+    }
+
+    Py_DECREF(module);
+    Py_XDECREF(funcobj);
+    return ret;
+}
+
+/* try to quit pygame modules, errors silenced */
+static void
+pg_mod_autoquit(const char *modname)
+{
+    PyObject *module, *funcobj, *temp;
+
+    module = PyImport_ImportModule(modname);
+    if (!module) {
+        PyErr_Clear();
+        return;
+    }
+
+    funcobj = PyObject_GetAttrString(module, "__PYGAMEquit__");
+
+    /* If we could not load __PYGAMEquit__, load quit function */
+    if (!funcobj)
+        funcobj = PyObject_GetAttrString(module, "quit");
+
+    /* Silence errors */
+    if (PyErr_Occurred())
+        PyErr_Clear();
+
+    if (funcobj) {
+        temp = PyObject_CallObject(funcobj, NULL);
+        Py_XDECREF(temp);
+    }
+
+    /* Silence errors */
+    if (PyErr_Occurred())
+        PyErr_Clear();
+
+    Py_DECREF(module);
+    Py_XDECREF(funcobj);
+}
+
+static PyObject *
+pg_init(PyObject *self)
+{
+    int i = 0, success = 0, fail = 0;
+
+    /* Put all the module names we want to init in this array */
+    const char *modnames[] = {
+        IMPPREFIX "display", /* Display first, this also inits event,time */
+        IMPPREFIX "joystick", IMPPREFIX "font", IMPPREFIX "freetype",
+        IMPPREFIX "mixer",
+        /* IMPPREFIX "_sdl2.controller", Is this required? Comment for now*/
+        NULL};
 
     if (!pg_CheckSDLVersions()) {
         return NULL;
@@ -282,52 +325,27 @@ pg_init(PyObject *self, PyObject *args)
     pg_sdl_was_init = SDL_Init(SDL_INIT_TIMER | SDL_INIT_NOPARACHUTE) == 0;
 #endif
 
-    pg_is_init = 1;  // Considered initialized at this point?
+    pg_env_blend_alpha_SDL2 = SDL_getenv("PYGAME_BLEND_ALPHA_SDL2");
 
     /* initialize all pygame modules */
-    allmodules = PyImport_GetModuleDict();
-    moduleslist = PyDict_Values(allmodules);
-    if (!allmodules || !moduleslist) {
-        return Py_BuildValue("(ii)", 0, 0);
-    }
-
-    if (pgVideo_AutoInit()) {
-        ++success;
-    }
-    else {
-        ++fail;
-    }
-
-    num = PyList_Size(moduleslist);
-    for (loop = 0; loop < num; ++loop) {
-        mod = PyList_GET_ITEM(moduleslist, loop);
-        if (!mod || !PyModule_Check(mod)) {
-            continue;
-        }
-        dict = PyModule_GetDict(mod);
-        func = PyDict_GetItemString(dict, "__PYGAMEinit__");
-        if (func && PyCallable_Check(func)) {
-            result = PyObject_CallObject(func, NULL);
-            if (result && PyObject_IsTrue(result)) {
-                ++success;
-            }
-            else {
-                PyErr_Clear();
-                ++fail;
-            }
-            Py_XDECREF(result);
+    for (i = 0; modnames[i]; i++) {
+        if (pg_mod_autoinit(modnames[i]))
+            success++;
+        else {
+            /* ImportError is neither counted as success nor failure */
+            if (!PyErr_ExceptionMatches(PyExc_ImportError))
+                fail++;
+            PyErr_Clear();
         }
     }
-    Py_DECREF(moduleslist);
 
+    pg_is_init = 1;
     return Py_BuildValue("(ii)", success, fail);
 }
 
 static void
 pg_atexit_quit(void)
 {
-    pgVideo_AutoQuit();
-
     /* Maybe it is safe to call SDL_quit more than once after an SDL_Init,
        but this is undocumented. So play it safe and only call after a
        successful SDL_Init.
@@ -339,67 +357,90 @@ pg_atexit_quit(void)
 }
 
 static PyObject *
-pg_get_sdl_version(PyObject *self, PyObject *args)
+pg_get_sdl_version(PyObject *self)
 {
-#if IS_SDLv1
-    const SDL_version *v;
-
-    v = SDL_Linked_Version();
-    return Py_BuildValue("iii", v->major, v->minor, v->patch);
-#else  /* IS_SDLv2 */
     SDL_version v;
 
     SDL_GetVersion(&v);
     return Py_BuildValue("iii", v.major, v.minor, v.patch);
-#endif /* IS_SDLv2 */
 }
 
 static PyObject *
-pg_get_sdl_byteorder(PyObject *self, PyObject *args)
+pg_get_sdl_byteorder(PyObject *self)
 {
     return PyLong_FromLong(SDL_BYTEORDER);
 }
 
-static PyObject *
-pg_quit(PyObject *self, PyObject *args)
-{
-    _pg_quit();
-    Py_RETURN_NONE;
-}
-
 static void
 _pg_quit(void)
 {
-    PyObject *quit;
-    PyObject *privatefuncs;
-    int num;
+    int num, i;
+    PyObject *quit, *privatefuncs, *temp;
 
-    pg_is_init = 0;  // Considered uninitialized at this point?
+    /* Put all the module names we want to quit in this array */
+    const char *modnames[] = {
+        /* IMPPREFIX "_sdl2.controller", Is this required?, comment for now */
+        IMPPREFIX "mixer",
+        IMPPREFIX "freetype",
+        IMPPREFIX "font",
+        IMPPREFIX "joystick",
+        IMPPREFIX "display", /* Display last, this also quits event,time */
+        NULL};
 
-    if (!pg_quit_functions) {
-        return;
+    if (pg_quit_functions) {
+        privatefuncs = pg_quit_functions;
+        pg_quit_functions = NULL;
+
+        pg_uninstall_parachute(); /* Is this done here, or can it be done
+                                     below? */
+        num = PyList_Size(privatefuncs);
+
+        /*quit funcs in reverse order*/
+        while (num--) {
+            quit = PyList_GET_ITEM(privatefuncs, num);
+            if (!quit) {
+                PyErr_Clear();
+                continue;
+            }
+
+            if (PyCallable_Check(quit)) {
+                temp = PyObject_CallObject(quit, NULL);
+                if (temp)
+                    Py_DECREF(temp);
+                else
+                    PyErr_Clear();
+            }
+            else if (PyCapsule_CheckExact(quit)) {
+                void *ptr = PyCapsule_GetPointer(quit, "quit");
+                (*(void (*)(void))ptr)();
+            }
+        }
+        Py_DECREF(privatefuncs);
     }
 
-    privatefuncs = pg_quit_functions;
-    pg_quit_functions = NULL;
-
-    pg_uninstall_parachute();
-    num = PyList_Size(privatefuncs);
-
-    /*quit in reverse order*/
-    while (num--) {
-        quit = PyList_GET_ITEM(privatefuncs, num);
-        if (PyCallable_Check(quit)) {
-            PyObject_CallObject(quit, NULL);
-        }
-        else if (PyCapsule_CheckExact(quit)) {
-            void *ptr = PyCapsule_GetPointer(quit, "quit");
-            (*(void (*)(void))ptr)();
-        }
+    /* quit all pygame modules */
+    for (i = 0; modnames[i]; i++) {
+        pg_mod_autoquit(modnames[i]);
     }
-    Py_DECREF(privatefuncs);
 
+    /* Because quit never errors */
+    if (PyErr_Occurred())
+        PyErr_Clear();
+
+    pg_is_init = 0;
+
+    /* Release the GIL here, because the timer thread cleanups should happen
+     * without deadlocking. */
+    Py_BEGIN_ALLOW_THREADS;
     pg_atexit_quit();
+    Py_END_ALLOW_THREADS;
+}
+
+static PyObject *
+pg_quit(PyObject *self)
+{
+    _pg_quit();
+    Py_RETURN_NONE;
 }
 
 static PyObject *
@@ -412,7 +453,18 @@ pg_get_init(PyObject *self, PyObject *args)
 static int
 pg_IntFromObj(PyObject *obj, int *val)
 {
-    int tmp_val = PyInt_AsLong(obj);
+    int tmp_val;
+
+    if (PyFloat_Check(obj)) {
+        /* Python3.8 complains with deprecation warnings if we pass
+         * floats to PyLong_AsLong.
+         */
+        double dv = PyFloat_AsDouble(obj);
+        tmp_val = (int)dv;
+    }
+    else {
+        tmp_val = PyLong_AsLong(obj);
+    }
 
     if (tmp_val == -1 && PyErr_Occurred()) {
         PyErr_Clear();
@@ -428,10 +480,12 @@ pg_IntFromObjIndex(PyObject *obj, int _index, int *val)
     int result = 0;
     PyObject *item = PySequence_GetItem(obj, _index);
 
-    if (item) {
-        result = pg_IntFromObj(item, val);
-        Py_DECREF(item);
+    if (!item) {
+        PyErr_Clear();
+        return 0;
     }
+    result = pg_IntFromObj(item, val);
+    Py_DECREF(item);
     return result;
 }
 
@@ -471,10 +525,12 @@ pg_FloatFromObjIndex(PyObject *obj, int _index, float *val)
     int result = 0;
     PyObject *item = PySequence_GetItem(obj, _index);
 
-    if (item) {
-        result = pg_FloatFromObj(item, val);
-        Py_DECREF(item);
+    if (!item) {
+        PyErr_Clear();
+        return 0;
     }
+    result = pg_FloatFromObj(item, val);
+    Py_DECREF(item);
     return result;
 }
 
@@ -497,14 +553,19 @@ pg_TwoFloatsFromObj(PyObject *obj, float *val1, float *val2)
 static int
 pg_UintFromObj(PyObject *obj, Uint32 *val)
 {
-    PyObject *longobj;
-
     if (PyNumber_Check(obj)) {
+        PyObject *longobj;
+
         if (!(longobj = PyNumber_Long(obj))) {
+            PyErr_Clear();
             return 0;
         }
         *val = (Uint32)PyLong_AsUnsignedLong(longobj);
         Py_DECREF(longobj);
+        if (PyErr_Occurred()) {
+            PyErr_Clear();
+            return 0;
+        }
         return 1;
     }
     return 0;
@@ -516,17 +577,19 @@ pg_UintFromObjIndex(PyObject *obj, int _index, Uint32 *val)
     int result = 0;
     PyObject *item = PySequence_GetItem(obj, _index);
 
-    if (item) {
-        result = pg_UintFromObj(item, val);
-        Py_DECREF(item);
+    if (!item) {
+        PyErr_Clear();
+        return 0;
     }
+    result = pg_UintFromObj(item, val);
+    Py_DECREF(item);
     return result;
 }
 
 static int
 pg_RGBAFromObj(PyObject *obj, Uint8 *RGBA)
 {
-    int length;
+    Py_ssize_t length;
     Uint32 val;
 
     if (PyTuple_Check(obj) && PyTuple_Size(obj) == 1) {
@@ -564,93 +627,28 @@ pg_RGBAFromObj(PyObject *obj, Uint8 *RGBA)
 }
 
 static PyObject *
-pg_get_error(PyObject *self, PyObject *args)
+pg_get_error(PyObject *self)
 {
-#if IS_SDLv1 && PY3 && !defined(PYPY_VERSION)
-    /* SDL 1's encoding is ambiguous */
-    PyObject *obj;
-    if (obj = PyUnicode_DecodeUTF8(SDL_GetError(),
-                                   strlen(SDL_GetError()), "strict"))
-        return obj;
-    PyErr_Clear();
-    return PyUnicode_DecodeLocale(SDL_GetError(), "surrogateescape");
-#else /* IS_SDLv2 || !PY3 */
-    return Text_FromUTF8(SDL_GetError());
-#endif /* IS_SDLv2 || !PY3 */
+    return PyUnicode_FromString(SDL_GetError());
 }
 
 static PyObject *
 pg_set_error(PyObject *s, PyObject *args)
 {
     char *errstring = NULL;
-#if PY2 || defined(PYPY_VERSION)
-    if (!PyArg_ParseTuple(args, "es",
-                          "UTF-8", &errstring))
-    {
+#if defined(PYPY_VERSION)
+    if (!PyArg_ParseTuple(args, "es", "UTF-8", &errstring))
         return NULL;
-    }
+
     SDL_SetError("%s", errstring);
     PyMem_Free(errstring);
-#else /* PY3 */
+#else
     if (!PyArg_ParseTuple(args, "s", &errstring)) {
         return NULL;
     }
     SDL_SetError("%s", errstring);
-#endif /* PY3 */
-    Py_RETURN_NONE;
-}
-
-/*video init needs to be here, because of it's
- *important init order priority
- */
-static void
-pgVideo_AutoQuit(void)
-{
-    if (SDL_WasInit(SDL_INIT_VIDEO)) {
-        SDL_QuitSubSystem(SDL_INIT_VIDEO);
-    }
-}
-
-static int
-pgVideo_AutoInit(void)
-{
-    if (!SDL_WasInit(SDL_INIT_VIDEO)) {
-        int status;
-#if defined(__APPLE__) && defined(darwin)
-        PyObject *module = PyImport_ImportModule("pygame.macosx");
-        PyObject *rval;
-
-        if (!module) {
-            printf("ERROR: pygame.macosx import FAILED\n");
-            return -1;
-        }
-
-        rval = PyObject_CallMethod(module, "Video_AutoInit", "");
-        Py_DECREF(module);
-        if (!rval) {
-            printf("ERROR: pygame.macosx.Video_AutoInit() call FAILED\n");
-            return -1;
-        }
-
-        status = PyObject_IsTrue(rval);
-        Py_DECREF(rval);
-        if (status != 1) {
-            return 0;
-        }
 #endif
-        status = SDL_InitSubSystem(SDL_INIT_VIDEO);
-        if (status) {
-            return 0;
-        }
-
-#if IS_SDLv1
-        SDL_EnableUNICODE(1);
-#endif /* IS_SDLv1 */
-
-        /*we special case the video quit to last now*/
-        /*pg_RegisterQuit(pgVideo_AutoQuit);*/
-    }
-    return 1;
+    Py_RETURN_NONE;
 }
 
 /*array interface*/
@@ -669,16 +667,10 @@ pgGetArrayStruct(PyObject *obj, PyObject **cobj_p, PyArrayInterface **inter_p)
         return -1;
     }
 
-#if PG_HAVE_COBJECT
-    if (PyCObject_Check(cobj)) {
-        inter = (PyArrayInterface *)PyCObject_AsVoidPtr(cobj);
-    }
-#endif
-#if PG_HAVE_CAPSULE
     if (PyCapsule_IsValid(cobj, NULL)) {
         inter = (PyArrayInterface *)PyCapsule_GetPointer(cobj, NULL);
     }
-#endif
+
     if (inter == NULL || inter->two != 2 /* conditional or */) {
         Py_DECREF(cobj);
         PyErr_SetString(PyExc_ValueError, "invalid array interface");
@@ -737,11 +729,7 @@ pgBuffer_AsArrayStruct(Py_buffer *view_p)
     if (!cinter_p) {
         return 0;
     }
-#if PY3
     capsule = PyCapsule_New(cinter_p, 0, _pg_capsule_PyMem_Free);
-#else
-    capsule = PyCObject_FromVoidPtr(cinter_p, PyMem_Free);
-#endif
     if (!capsule) {
         PyMem_Free(cinter_p);
         return 0;
@@ -786,13 +774,11 @@ _pg_new_capsuleinterface(Py_buffer *view_p)
     return cinter_p;
 }
 
-#if PY3
 static void
 _pg_capsule_PyMem_Free(PyObject *capsule)
 {
     PyMem_Free(PyCapsule_GetPointer(capsule, 0));
 }
-#endif
 
 static int
 _pg_as_arrayinter_flags(Py_buffer *view_p)
@@ -815,9 +801,9 @@ _pg_as_arrayinter_flags(Py_buffer *view_p)
 static PyObject *
 pg_view_get_typestr_obj(Py_buffer *view)
 {
-    return Text_FromFormat("%c%c%i", _pg_as_arrayinter_byteorder(view),
-                           _pg_as_arrayinter_typekind(view),
-                           (int)view->itemsize);
+    return PyUnicode_FromFormat("%c%c%i", _pg_as_arrayinter_byteorder(view),
+                                _pg_as_arrayinter_typekind(view),
+                                (int)view->itemsize);
 }
 
 static PyObject *
@@ -831,7 +817,7 @@ pg_view_get_shape_obj(Py_buffer *view)
         return 0;
     }
     for (i = 0; i < view->ndim; ++i) {
-        lengthobj = PyInt_FromLong((long)view->shape[i]);
+        lengthobj = PyLong_FromLong((long)view->shape[i]);
         if (!lengthobj) {
             Py_DECREF(shapeobj);
             return 0;
@@ -852,7 +838,7 @@ pg_view_get_strides_obj(Py_buffer *view)
         return 0;
     }
     for (i = 0; i < view->ndim; ++i) {
-        lengthobj = PyInt_FromLong((long)view->strides[i]);
+        lengthobj = PyLong_FromLong((long)view->strides[i]);
         if (!lengthobj) {
             Py_DECREF(shapeobj);
             return 0;
@@ -952,7 +938,7 @@ _pg_shape_as_tuple(PyArrayInterface *inter_p)
         return 0;
     }
     for (i = 0; i < inter_p->nd; ++i) {
-        lengthobj = PyInt_FromLong((long)inter_p->shape[i]);
+        lengthobj = PyLong_FromLong((long)inter_p->shape[i]);
         if (!lengthobj) {
             Py_DECREF(shapeobj);
             return 0;
@@ -965,11 +951,11 @@ _pg_shape_as_tuple(PyArrayInterface *inter_p)
 static PyObject *
 _pg_typekind_as_str(PyArrayInterface *inter_p)
 {
-    return Text_FromFormat(
+    return PyUnicode_FromFormat(
         "%c%c%i",
         inter_p->itemsize > 1
-            ? (inter_p->flags & PAI_NOTSWAPPED ? PAI_MY_ENDIAN
-                                               : PAI_OTHER_ENDIAN)
+            ? ((inter_p->flags & PAI_NOTSWAPPED) ? PAI_MY_ENDIAN
+                                                 : PAI_OTHER_ENDIAN)
             : '|',
         inter_p->typekind, inter_p->itemsize);
 }
@@ -985,7 +971,7 @@ _pg_strides_as_tuple(PyArrayInterface *inter_p)
         return 0;
     }
     for (i = 0; i < inter_p->nd; ++i) {
-        lengthobj = PyInt_FromLong((long)inter_p->strides[i]);
+        lengthobj = PyLong_FromLong((long)inter_p->strides[i]);
         if (!lengthobj) {
             Py_DECREF(stridesobj);
             return 0;
@@ -1026,7 +1012,6 @@ pgObject_GetBuffer(PyObject *obj, pg_buffer *pg_view_p, int flags)
     PyObject *cobj = 0;
     PyObject *dict = 0;
     PyArrayInterface *inter_p = 0;
-    char *fchar_p;
     int success = 0;
 
     pg_view_p->release_buffer = _pg_release_buffer_generic;
@@ -1038,9 +1023,9 @@ pgObject_GetBuffer(PyObject *obj, pg_buffer *pg_view_p, int flags)
     flags |= PyBUF_PYGAME;
 #endif
 
-#if PG_ENABLE_NEWBUF
-
     if (PyObject_CheckBuffer(obj)) {
+        char *fchar_p;
+
         if (PyObject_GetBuffer(obj, view_p, flags)) {
             return -1;
         }
@@ -1116,7 +1101,6 @@ pgObject_GetBuffer(PyObject *obj, pg_buffer *pg_view_p, int flags)
         success = 1;
     }
 
-#endif
     if (!success && pgGetArrayStruct(obj, &cobj, &inter_p) == 0) {
         if (pgArrayStruct_AsBuffer(pg_view_p, cobj, inter_p, flags)) {
             Py_DECREF(cobj);
@@ -1239,7 +1223,7 @@ _pg_arraystruct_as_buffer(Py_buffer *view_p, PyObject *cobj,
     pgViewInternals *internal_p;
     Py_ssize_t sz =
         (sizeof(pgViewInternals) + (2 * inter_p->nd - 1) * sizeof(Py_ssize_t));
-    int readonly = inter_p->flags & PAI_WRITEABLE ? 0 : 1;
+    int readonly = (inter_p->flags & PAI_WRITEABLE) ? 0 : 1;
     Py_ssize_t i;
 
     view_p->obj = 0;
@@ -1336,8 +1320,8 @@ _pg_arraystruct_to_format(char *format, PyArrayInterface *inter_p,
     assert(max_format_len >= 4);
     switch (inter_p->typekind) {
         case 'i':
-            *fchar_p = (inter_p->flags & PAI_NOTSWAPPED ? BUF_MY_ENDIAN
-                                                        : BUF_OTHER_ENDIAN);
+            *fchar_p = ((inter_p->flags & PAI_NOTSWAPPED) ? BUF_MY_ENDIAN
+                                                          : BUF_OTHER_ENDIAN);
             ++fchar_p;
             switch (inter_p->itemsize) {
                 case 1:
@@ -1360,8 +1344,8 @@ _pg_arraystruct_to_format(char *format, PyArrayInterface *inter_p,
             }
             break;
         case 'u':
-            *fchar_p = (inter_p->flags & PAI_NOTSWAPPED ? BUF_MY_ENDIAN
-                                                        : BUF_OTHER_ENDIAN);
+            *fchar_p = ((inter_p->flags & PAI_NOTSWAPPED) ? BUF_MY_ENDIAN
+                                                          : BUF_OTHER_ENDIAN);
             ++fchar_p;
             switch (inter_p->itemsize) {
                 case 1:
@@ -1384,8 +1368,8 @@ _pg_arraystruct_to_format(char *format, PyArrayInterface *inter_p,
             }
             break;
         case 'f':
-            *fchar_p = (inter_p->flags & PAI_NOTSWAPPED ? BUF_MY_ENDIAN
-                                                        : BUF_OTHER_ENDIAN);
+            *fchar_p = ((inter_p->flags & PAI_NOTSWAPPED) ? BUF_MY_ENDIAN
+                                                          : BUF_OTHER_ENDIAN);
             ++fchar_p;
             switch (inter_p->itemsize) {
                 case 4:
@@ -1510,14 +1494,15 @@ _pg_typestr_check(PyObject *op)
         return -1;
     }
     if (PyUnicode_Check(op)) {
-        if (PyUnicode_GET_SIZE(op) != 3) {
+        Py_ssize_t len = PyUnicode_GET_LENGTH(op);
+        if (len != 3) {
             PyErr_SetString(PyExc_ValueError,
                             "expected 'typestr' to be length 3");
             return -1;
         }
     }
-    else if (Bytes_Check(op)) {
-        if (Bytes_GET_SIZE(op) != 3) {
+    else if (PyBytes_Check(op)) {
+        if (PyBytes_GET_SIZE(op) != 3) {
             PyErr_SetString(PyExc_ValueError,
                             "expected 'typestr' to be length 3");
             return -1;
@@ -1549,7 +1534,7 @@ _pg_data_check(PyObject *op)
         return -1;
     }
     item = PyTuple_GET_ITEM(op, 0);
-    if (!INT_CHECK(item)) {
+    if (!PyLong_Check(item)) {
         PyErr_SetString(PyExc_ValueError,
                         "expected an int for item 0 of 'data'");
         return -1;
@@ -1581,7 +1566,7 @@ _pg_is_int_tuple(PyObject *op)
     n = PyTuple_GET_SIZE(op);
     for (i = 0; i != n; ++i) {
         ip = PyTuple_GET_ITEM(op, i);
-        if (!INT_CHECK(ip)) {
+        if (!PyLong_Check(ip)) {
             return 0;
         }
     }
@@ -1594,8 +1579,7 @@ _pg_values_as_buffer(Py_buffer *view_p, int flags, PyObject *typestr,
 {
     Py_ssize_t ndim = PyTuple_GET_SIZE(shape);
     pgViewInternals *internal_p;
-    Py_ssize_t sz;
-    int i;
+    Py_ssize_t sz, i;
 
     assert(ndim > 0);
     view_p->obj = 0;
@@ -1711,7 +1695,7 @@ _pg_int_tuple_as_ssize_arr(PyObject *tp, Py_ssize_t *arr)
     Py_ssize_t n = PyTuple_GET_SIZE(tp);
 
     for (i = 0; i != n; ++i) {
-        arr[i] = PyInt_AsSsize_t(PyTuple_GET_ITEM(tp, i));
+        arr[i] = PyLong_AsSsize_t(PyTuple_GET_ITEM(tp, i));
         if (arr[i] == -1 && PyErr_Occurred()) {
             return -1;
         }
@@ -1736,7 +1720,7 @@ _pg_typestr_as_format(PyObject *sp, char *format, Py_ssize_t *itemsize_p)
     else {
         Py_INCREF(sp);
     }
-    typestr = Bytes_AsString(sp);
+    typestr = PyBytes_AsString(sp);
     switch (typestr[0]) {
         case PAI_MY_ENDIAN:
         case '|':
@@ -1894,7 +1878,6 @@ _pg_typestr_as_format(PyObject *sp, char *format, Py_ssize_t *itemsize_p)
     return 0;
 }
 
-#if IS_SDLv2
 /*Default window(display)*/
 static SDL_Window *
 pg_GetDefaultWindow(void)
@@ -1915,28 +1898,30 @@ pg_SetDefaultWindow(SDL_Window *win)
     pg_default_window = win;
 }
 
-static PyObject *
+static pgSurfaceObject *
 pg_GetDefaultWindowSurface(void)
 {
-    /*return a borrowed reference*/
+    /* return a borrowed reference*/
     return pg_default_screen;
 }
 
 static void
-pg_SetDefaultWindowSurface(PyObject *screen)
+pg_SetDefaultWindowSurface(pgSurfaceObject *screen)
 {
     /*a screen surface can be replaced with itself*/
     if (screen == pg_default_screen) {
         return;
     }
     Py_XINCREF(screen);
-    if (pg_default_screen) {
-        pgSurface_AsSurface(pg_default_screen) = NULL;
-        Py_DECREF(pg_default_screen);
-    }
+    Py_XDECREF(pg_default_screen);
     pg_default_screen = screen;
 }
-#endif /* IS_SDLv2 */
+
+static char *
+pg_EnvShouldBlendAlphaSDL2(void)
+{
+    return pg_env_blend_alpha_SDL2;
+}
 
 /*error signal handlers(replacing SDL parachute)*/
 static void
@@ -2064,33 +2049,33 @@ pg_do_segfault(PyObject *self, PyObject *args)
 }
 
 static PyMethodDef _base_methods[] = {
-    {"init", pg_init, METH_NOARGS, DOC_PYGAMEINIT},
-    {"quit", pg_quit, METH_NOARGS, DOC_PYGAMEQUIT},
-    {"get_init", pg_get_init, METH_NOARGS, DOC_PYGAMEGETINIT},
-    {"register_quit", pg_register_quit, METH_O, DOC_PYGAMEREGISTERQUIT},
-    {"get_error", pg_get_error, METH_NOARGS, DOC_PYGAMEGETERROR},
+    {"init", (PyCFunction)pg_init, METH_NOARGS, DOC_PYGAMEINIT},
+    {"quit", (PyCFunction)pg_quit, METH_NOARGS, DOC_PYGAMEQUIT},
+    {"get_init", (PyCFunction)pg_get_init, METH_NOARGS, DOC_PYGAMEGETINIT},
+    {"register_quit", (PyCFunction)pg_register_quit, METH_O,
+     DOC_PYGAMEREGISTERQUIT},
+    {"get_error", (PyCFunction)pg_get_error, METH_NOARGS, DOC_PYGAMEGETERROR},
     {"set_error", pg_set_error, METH_VARARGS, DOC_PYGAMESETERROR},
-    {"get_sdl_version", pg_get_sdl_version, METH_NOARGS,
+    {"get_sdl_version", (PyCFunction)pg_get_sdl_version, METH_NOARGS,
      DOC_PYGAMEGETSDLVERSION},
-    {"get_sdl_byteorder", pg_get_sdl_byteorder, METH_NOARGS,
+    {"get_sdl_byteorder", (PyCFunction)pg_get_sdl_byteorder, METH_NOARGS,
      DOC_PYGAMEGETSDLBYTEORDER},
 
-    {"get_array_interface", pg_get_array_interface, METH_O,
+    {"get_array_interface", (PyCFunction)pg_get_array_interface, METH_O,
      "return an array struct interface as an interface dictionary"},
 
-    {"segfault", pg_do_segfault, METH_NOARGS, "crash"},
+    {"segfault", (PyCFunction)pg_do_segfault, METH_NOARGS, "crash"},
     {NULL, NULL, 0, NULL}};
 
 MODINIT_DEFINE(base)
 {
     static int is_loaded = 0;
     PyObject *module, *dict, *apiobj;
-    PyObject *atexit, *atexit_register = NULL, *quit, *rval;
+    PyObject *atexit_register = NULL;
     PyObject *pgExc_SDLError;
     int ecode;
     static void *c_api[PYGAMEAPI_BASE_NUMSLOTS];
 
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          "base",
                                          "",
@@ -2100,31 +2085,27 @@ MODINIT_DEFINE(base)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     if (!is_loaded) {
         /* import need modules. Do this first so if there is an error
            the module is not loaded.
         */
-        atexit = PyImport_ImportModule("atexit");
+        PyObject *atexit = PyImport_ImportModule("atexit");
+
         if (!atexit) {
-            MODINIT_ERROR;
+            return NULL;
         }
         atexit_register = PyObject_GetAttrString(atexit, "register");
         Py_DECREF(atexit);
         if (!atexit_register) {
-            MODINIT_ERROR;
+            return NULL;
         }
     }
 
     /* create the module */
-#if PY3
     module = PyModule_Create(&_module);
-#else
-    module = Py_InitModule3(MODPREFIX "base", _base_methods, DOC_PYGAME);
-#endif
     if (module == NULL) {
-        MODINIT_ERROR;
+        return NULL;
     }
     dict = PyModule_GetDict(module);
 
@@ -2133,35 +2114,31 @@ MODINIT_DEFINE(base)
         PyErr_NewException("pygame.error", PyExc_RuntimeError, NULL);
     if (pgExc_SDLError == NULL) {
         Py_XDECREF(atexit_register);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
     ecode = PyDict_SetItemString(dict, "error", pgExc_SDLError);
     Py_DECREF(pgExc_SDLError);
     if (ecode) {
         Py_XDECREF(atexit_register);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
-#if PG_ENABLE_NEWBUF
     pgExc_BufferError =
         PyErr_NewException("pygame.BufferError", PyExc_BufferError, NULL);
-#else
-    pgExc_BufferError =
-        PyErr_NewException("pygame.BufferError", PyExc_RuntimeError, NULL);
-#endif
+
     if (pgExc_SDLError == NULL) {
         Py_XDECREF(atexit_register);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
     ecode = PyDict_SetItemString(dict, "BufferError", pgExc_BufferError);
     if (ecode) {
         Py_DECREF(pgExc_BufferError);
         Py_XDECREF(atexit_register);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
     /* export the c api */
@@ -2175,8 +2152,8 @@ MODINIT_DEFINE(base)
     c_api[7] = pg_TwoFloatsFromObj;
     c_api[8] = pg_UintFromObj;
     c_api[9] = pg_UintFromObjIndex;
-    c_api[10] = pgVideo_AutoQuit;
-    c_api[11] = pgVideo_AutoInit;
+    c_api[10] = pg_mod_autoinit;
+    c_api[11] = pg_mod_autoquit;
     c_api[12] = pg_RGBAFromObj;
     c_api[13] = pgBuffer_AsArrayInterface;
     c_api[14] = pgBuffer_AsArrayStruct;
@@ -2184,15 +2161,12 @@ MODINIT_DEFINE(base)
     c_api[16] = pgBuffer_Release;
     c_api[17] = pgDict_AsBuffer;
     c_api[18] = pgExc_BufferError;
-#if IS_SDLv1
-#define FILLED_SLOTS 19
-#else /* IS_SDLv2 */
     c_api[19] = pg_GetDefaultWindow;
     c_api[20] = pg_SetDefaultWindow;
     c_api[21] = pg_GetDefaultWindowSurface;
     c_api[22] = pg_SetDefaultWindowSurface;
-#define FILLED_SLOTS 23
-#endif /* IS_SDLv2 */
+    c_api[23] = pg_EnvShouldBlendAlphaSDL2;
+#define FILLED_SLOTS 24
 
 #if PYGAMEAPI_BASE_NUMSLOTS != FILLED_SLOTS
 #error export slot count mismatch
@@ -2202,41 +2176,43 @@ MODINIT_DEFINE(base)
     if (apiobj == NULL) {
         Py_XDECREF(atexit_register);
         Py_DECREF(pgExc_BufferError);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
     ecode = PyDict_SetItemString(dict, PYGAMEAPI_LOCAL_ENTRY, apiobj);
     Py_DECREF(apiobj);
     if (ecode) {
         Py_XDECREF(atexit_register);
         Py_DECREF(pgExc_BufferError);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
-    if (PyModule_AddIntConstant(module, "HAVE_NEWBUF", PG_ENABLE_NEWBUF)) {
+    if (PyModule_AddIntConstant(module, "HAVE_NEWBUF", 1)) {
         Py_XDECREF(atexit_register);
         Py_DECREF(pgExc_BufferError);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
     if (!is_loaded) {
         /*some intialization*/
-        quit = PyObject_GetAttrString(module, "quit");
+        PyObject *quit = PyObject_GetAttrString(module, "quit");
+        PyObject *rval;
+
         if (quit == NULL) { /* assertion */
             Py_DECREF(atexit_register);
             Py_DECREF(pgExc_BufferError);
-            DECREF_MOD(module);
-            MODINIT_ERROR;
+            Py_DECREF(module);
+            return NULL;
         }
         rval = PyObject_CallFunctionObjArgs(atexit_register, quit, NULL);
         Py_DECREF(atexit_register);
         Py_DECREF(quit);
         if (rval == NULL) {
-            DECREF_MOD(module);
+            Py_DECREF(module);
             Py_DECREF(pgExc_BufferError);
-            MODINIT_ERROR;
+            return NULL;
         }
         Py_DECREF(rval);
         Py_AtExit(pg_atexit_quit);
@@ -2254,5 +2230,5 @@ MODINIT_DEFINE(base)
 #endif
     }
     is_loaded = 1;
-    MODINIT_RETURN(module);
+    return module;
 }
