@@ -140,8 +140,8 @@ v4l2_read_raw(pgCameraObject *self)
 
     assert(buf.index < self->n_buffers);
 
-    raw = Bytes_FromStringAndSize(self->buffers[buf.index].start,
-                                  self->buffers[buf.index].length);
+    raw = PyBytes_FromStringAndSize(self->buffers[buf.index].start,
+                                    self->buffers[buf.index].length);
 
     if (-1 == v4l2_xioctl(self->fd, VIDIOC_QBUF, &buf)) {
         PyErr_Format(PyExc_SystemError, "ioctl(VIDIOC_QBUF) failure : %d, %s",
@@ -334,10 +334,6 @@ v4l2_process_image(pgCameraObject *self, const void *image,
 }
 
 /* query each buffer to see if it contains a frame ready to take */
-/* FIXME: There needs to be a better way to implement non-blocking frame
-   grabbing than only doing a get_image if query_image returns true. Many
-   cameras will always return false, and will only respond to blocking calls.
- */
 int
 v4l2_query_buffer(pgCameraObject *self)
 {
