@@ -33,8 +33,8 @@ static PyObject *
 pgCD_New(int id);
 #define pgCD_Check(x) ((x)->ob_type == &pgCD_Type)
 
-static void
-cdrom_autoquit(void)
+static PyObject *
+cdrom_quit(PyObject *self)
 {
     int loop;
     for (loop = 0; loop < CDROM_MAXDRIVES; ++loop) {
@@ -47,38 +47,15 @@ cdrom_autoquit(void)
     if (SDL_WasInit(SDL_INIT_CDROM)) {
         SDL_QuitSubSystem(SDL_INIT_CDROM);
     }
-}
-
-static PyObject *
-cdrom_autoinit(PyObject *self)
-{
-    if (!SDL_WasInit(SDL_INIT_CDROM)) {
-        if (SDL_InitSubSystem(SDL_INIT_CDROM)) {
-            return PyInt_FromLong(0);
-        }
-        pg_RegisterQuit(cdrom_autoquit);
-    }
-    return PyInt_FromLong(1);
-}
-
-static PyObject *
-cdrom_quit(PyObject *self)
-{
-    cdrom_autoquit();
     Py_RETURN_NONE;
 }
 
 static PyObject *
 cdrom_init(PyObject *self)
 {
-    PyObject *result;
-    int istrue;
-
-    result = cdrom_autoinit(self);
-    istrue = PyObject_IsTrue(result);
-    Py_DECREF(result);
-    if (!istrue) {
-        return RAISE(pgExc_SDLError, SDL_GetError());
+    if (!SDL_WasInit(SDL_INIT_CDROM)) {
+        if (SDL_InitSubSystem(SDL_INIT_CDROM))
+            return RAISE(pgExc_SDLError, SDL_GetError());
     }
     Py_RETURN_NONE;
 }
@@ -86,7 +63,7 @@ cdrom_init(PyObject *self)
 static PyObject *
 get_init(PyObject *self)
 {
-    return PyInt_FromLong(SDL_WasInit(SDL_INIT_CDROM) != 0);
+    return PyBool_FromLong(SDL_WasInit(SDL_INIT_CDROM) != 0);
 }
 
 static void
@@ -111,7 +88,7 @@ static PyObject *
 get_count(PyObject *self)
 {
     CDROM_INIT_CHECK();
-    return PyInt_FromLong(SDL_CDNumDrives());
+    return PyLong_FromLong(SDL_CDNumDrives());
 }
 
 static PyObject *
@@ -147,7 +124,7 @@ static PyObject *
 cd_get_init(PyObject *self, PyObject *args)
 {
     int cd_id = pgCD_AsID(self);
-    return PyInt_FromLong(cdrom_drivedata[cd_id] != NULL);
+    return PyBool_FromLong(cdrom_drivedata[cd_id] != NULL);
 }
 
 static PyObject *
@@ -303,7 +280,7 @@ cd_get_empty(PyObject *self, PyObject *args)
     }
 
     status = SDL_CDStatus(cdrom);
-    return PyInt_FromLong(status == CD_TRAYEMPTY);
+    return PyLong_FromLong(status == CD_TRAYEMPTY);
 }
 
 static PyObject *
@@ -319,7 +296,7 @@ cd_get_busy(PyObject *self, PyObject *args)
     }
 
     status = SDL_CDStatus(cdrom);
-    return PyInt_FromLong(status == CD_PLAYING);
+    return PyLong_FromLong(status == CD_PLAYING);
 }
 
 static PyObject *
@@ -335,7 +312,7 @@ cd_get_paused(PyObject *self, PyObject *args)
     }
 
     status = SDL_CDStatus(cdrom);
-    return PyInt_FromLong(status == CD_PAUSED);
+    return PyLong_FromLong(status == CD_PAUSED);
 }
 
 static PyObject *
@@ -370,14 +347,14 @@ cd_get_numtracks(PyObject *self, PyObject *args)
     }
 
     SDL_CDStatus(cdrom);
-    return PyInt_FromLong(cdrom->numtracks);
+    return PyLong_FromLong(cdrom->numtracks);
 }
 
 static PyObject *
 cd_get_id(PyObject *self, PyObject *args)
 {
     int cd_id = pgCD_AsID(self);
-    return PyInt_FromLong(cd_id);
+    return PyLong_FromLong(cd_id);
 }
 
 static PyObject *
@@ -385,7 +362,7 @@ cd_get_name(PyObject *self, PyObject *args)
 {
     int cd_id = pgCD_AsID(self);
     CDROM_INIT_CHECK();
-    return Text_FromUTF8(SDL_CDName(cd_id));
+    return PyUnicode_FromString(SDL_CDName(cd_id));
 }
 
 static PyObject *
@@ -408,7 +385,7 @@ cd_get_track_audio(PyObject *self, PyObject *args)
         return RAISE(PyExc_IndexError, "Invalid track number");
     }
 
-    return PyInt_FromLong(cdrom->track[track].type == SDL_AUDIO_TRACK);
+    return PyLong_FromLong(cdrom->track[track].type == SDL_AUDIO_TRACK);
 }
 
 static PyObject *
@@ -488,7 +465,7 @@ cd_get_all(PyObject *self, PyObject *args)
             Py_DECREF(tuple);
             return NULL;
         }
-        PyTuple_SET_ITEM(item, 0, PyInt_FromLong(audio));
+        PyTuple_SET_ITEM(item, 0, PyLong_FromLong(audio));
         PyTuple_SET_ITEM(item, 1, PyFloat_FromDouble(start));
         PyTuple_SET_ITEM(item, 2, PyFloat_FromDouble(end));
         PyTuple_SET_ITEM(item, 3, PyFloat_FromDouble(length));
@@ -525,43 +502,43 @@ static PyMethodDef cd_methods[] = {
     {NULL, NULL, 0, NULL}};
 
 static PyTypeObject pgCD_Type = {
-    TYPE_HEAD(NULL, 0) "CD", /* name */
-    sizeof(pgCDObject),      /* basic size */
-    0,                       /* itemsize */
-    cd_dealloc,              /* dealloc */
-    0,                       /* print */
-    0,                       /* getattr */
-    0,                       /* setattr */
-    0,                       /* compare */
-    0,                       /* repr */
-    0,                       /* as_number */
-    0,                       /* as_sequence */
-    0,                       /* as_mapping */
-    0,                       /* hash */
-    0,                       /* call */
-    0,                       /* str */
-    0,                       /* tp_getattro */
-    0,                       /* tp_setattro */
-    0,                       /* tp_as_buffer */
-    0,                       /* flags */
-    DOC_PYGAMECDROMCD,       /* Documentation string */
-    0,                       /* tp_traverse */
-    0,                       /* tp_clear */
-    0,                       /* tp_richcompare */
-    0,                       /* tp_weaklistoffset */
-    0,                       /* tp_iter */
-    0,                       /* tp_iternext */
-    cd_methods,              /* tp_methods */
-    0,                       /* tp_members */
-    0,                       /* tp_getset */
-    0,                       /* tp_base */
-    0,                       /* tp_dict */
-    0,                       /* tp_descr_get */
-    0,                       /* tp_descr_set */
-    0,                       /* tp_dictoffset */
-    0,                       /* tp_init */
-    0,                       /* tp_alloc */
-    0,                       /* tp_new */
+    PyVarObject_HEAD_INIT(NULL, 0) "CD", /* name */
+    sizeof(pgCDObject),                  /* basic size */
+    0,                                   /* itemsize */
+    cd_dealloc,                          /* dealloc */
+    0,                                   /* print */
+    0,                                   /* getattr */
+    0,                                   /* setattr */
+    0,                                   /* compare */
+    0,                                   /* repr */
+    0,                                   /* as_number */
+    0,                                   /* as_sequence */
+    0,                                   /* as_mapping */
+    0,                                   /* hash */
+    0,                                   /* call */
+    0,                                   /* str */
+    0,                                   /* tp_getattro */
+    0,                                   /* tp_setattro */
+    0,                                   /* tp_as_buffer */
+    0,                                   /* flags */
+    DOC_PYGAMECDROMCD,                   /* Documentation string */
+    0,                                   /* tp_traverse */
+    0,                                   /* tp_clear */
+    0,                                   /* tp_richcompare */
+    0,                                   /* tp_weaklistoffset */
+    0,                                   /* tp_iter */
+    0,                                   /* tp_iternext */
+    cd_methods,                          /* tp_methods */
+    0,                                   /* tp_members */
+    0,                                   /* tp_getset */
+    0,                                   /* tp_base */
+    0,                                   /* tp_dict */
+    0,                                   /* tp_descr_get */
+    0,                                   /* tp_descr_set */
+    0,                                   /* tp_dictoffset */
+    0,                                   /* tp_init */
+    0,                                   /* tp_alloc */
+    0,                                   /* tp_new */
 };
 
 static PyObject *
@@ -584,8 +561,6 @@ pgCD_New(int id)
 }
 
 static PyMethodDef _cdrom_methods[] = {
-    {"__PYGAMEinit__", (PyCFunction)cdrom_autoinit, METH_NOARGS,
-     "auto initialize function"},
     {"init", (PyCFunction)cdrom_init, METH_NOARGS, DOC_PYGAMECDROMINIT},
     {"quit", (PyCFunction)cdrom_quit, METH_NOARGS, DOC_PYGAMECDROMQUIT},
     {"get_init", (PyCFunction)get_init, METH_NOARGS, DOC_PYGAMECDROMGETINIT},
@@ -600,7 +575,6 @@ MODINIT_DEFINE(cdrom)
     int ecode;
     static void *c_api[PYGAMEAPI_CDROM_NUMSLOTS];
 
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          "cdrom",
                                          DOC_PYGAMECDROM,
@@ -610,36 +584,30 @@ MODINIT_DEFINE(cdrom)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     /* imported needed apis; Do this first so if there is an error
        the module is not loaded.
     */
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     /* type preparation */
     if (PyType_Ready(&pgCD_Type) == -1) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     /* create the module */
-#if PY3
     module = PyModule_Create(&_module);
-#else
-    module =
-        Py_InitModule3(MODPREFIX "cdrom", _cdrom_methods, DOC_PYGAMECDROM);
-#endif
     if (module == NULL) {
-        MODINIT_ERROR;
+        return NULL;
     }
     dict = PyModule_GetDict(module);
 
     if (PyDict_SetItemString(dict, "CDType", (PyObject *)&pgCD_Type) == -1) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 
     /* export the c api */
@@ -647,15 +615,15 @@ MODINIT_DEFINE(cdrom)
     c_api[1] = pgCD_New;
     apiobj = encapsulate_api(c_api, "cdrom");
     if (apiobj == NULL) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
     ecode = PyDict_SetItemString(dict, PYGAMEAPI_LOCAL_ENTRY, apiobj);
     Py_DECREF(apiobj);
 
     if (ecode == -1) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
-    MODINIT_RETURN(module);
+    return module;
 }
