@@ -63,6 +63,7 @@
 #else
 #include <strings.h>
 #endif
+#include <string.h>
 
 #define JPEG_QUALITY 85
 
@@ -70,6 +71,15 @@
 static SDL_mutex *_pg_img_mutex = 0;
 #endif /* WITH_THREAD */
 
+#ifdef WIN32
+#include <windows.h>
+#define pg_RWflush(rwops) \
+    (FlushFileBuffers((HANDLE)(rwops)->hidden.windowsio.h) ? 0 : -1)
+
+#else /* ~WIN32 */
+#define pg_RWflush(rwops) (fflush((rwops)->hidden.stdio.fp) ? -1 : 0)
+#endif /* ~WIN32 */
+
 static const char *
 find_extension(const char *fullname)
 {
@@ -91,117 +101,46 @@ image_load_ext(PyObject *self, PyObject *arg)
 {
     PyObject *obj;
     PyObject *final;
-    PyObject *oencoded;
-    PyObject *oname;
-    size_t namelen;
     const char *name = NULL;
-    const char *cext;
     char *ext = NULL;
     SDL_Surface *surf;
-    SDL_RWops *rw;
+    SDL_RWops *rw = NULL;
+    int lock_mutex = 0;
 
     if (!PyArg_ParseTuple(arg, "O|s", &obj, &name)) {
         return NULL;
     }
 
-    oencoded = pg_EncodeString(obj, "UTF-8", NULL, pgExc_SDLError);
-    if (oencoded == NULL) {
+    rw = pgRWops_FromObject(obj);
+    if (rw == NULL) /* stop on NULL, error already set */
         return NULL;
-    }
-    if (oencoded != Py_None) {
-        name = Bytes_AS_STRING(oencoded);
+    ext = pgRWops_GetFileExtension(rw);
+    if (name) /* override extension with namehint if given */
+        ext = find_extension(name);
+
 #ifdef WITH_THREAD
-        namelen = Bytes_GET_SIZE(oencoded);
-        Py_BEGIN_ALLOW_THREADS;
-        if (namelen > 4 && !strcasecmp(name + namelen - 4, ".gif")) {
-            /* using multiple threads does not work for (at least) SDL_image <= 2.0.4 */
-            SDL_LockMutex(_pg_img_mutex);
-            surf = IMG_Load(name);
-            SDL_UnlockMutex(_pg_img_mutex);
-        }
-        else {
-            surf = IMG_Load(name);
-        }
-        Py_END_ALLOW_THREADS;
-#else /* ~WITH_THREAD */
-        surf = IMG_Load(name);
-#endif /* WITH_THREAD */
-        Py_DECREF(oencoded);
+    if (ext)
+        lock_mutex = !strcasecmp(ext, "gif");
+    Py_BEGIN_ALLOW_THREADS;
+    if (0) {
+        /* using multiple threads does not work for (at least) SDL_image
+         * <= 2.0.4 */
+        SDL_LockMutex(_pg_img_mutex);
+        surf = IMG_LoadTyped_RW(rw, 1, ext);
+        SDL_UnlockMutex(_pg_img_mutex);
     }
     else {
-#ifdef WITH_THREAD
-        int lock_mutex = 0;
-#endif /* WITH_THREAD */
-        Py_DECREF(oencoded);
-        oencoded = NULL;
-#if PY2
-        if (name == NULL && PyFile_Check(obj)) {
-            oencoded = PyFile_Name(obj);
-            if (oencoded == NULL) {
-                /* This should never happen */
-                return NULL;
-            }
-            Py_INCREF(oencoded);
-            name = Bytes_AS_STRING(oencoded);
-        }
-#endif
-        if (name == NULL) {
-            oname = PyObject_GetAttrString(obj, "name");
-            if (oname != NULL) {
-                oencoded = pg_EncodeString(oname, "UTF-8", NULL, NULL);
-                Py_DECREF(oname);
-                if (oencoded == NULL) {
-                    return NULL;
-                }
-                if (oencoded != Py_None) {
-                    name = Bytes_AS_STRING(oencoded);
-                }
-            }
-            else {
-                PyErr_Clear();
-            }
-        }
-        rw = pgRWops_FromFileObject(obj);
-        if (rw == NULL) {
-            Py_XDECREF(oencoded);
-            return NULL;
-        }
-
-        cext = find_extension(name);
-        if (cext != NULL) {
-            ext = (char *)PyMem_Malloc(strlen(cext) + 1);
-            if (ext == NULL) {
-                Py_XDECREF(oencoded);
-                return PyErr_NoMemory();
-            }
-            strcpy(ext, cext);
-#ifdef WITH_THREAD
-            lock_mutex = !strcasecmp(ext, "gif");
-#endif /* WITH_THREAD */
-        }
-        Py_XDECREF(oencoded);
-#ifdef WITH_THREAD
-        Py_BEGIN_ALLOW_THREADS;
-        if (lock_mutex) {
-            /* using multiple threads does not work for (at least) SDL_image <= 2.0.4 */
-            SDL_LockMutex(_pg_img_mutex);
-            surf = IMG_LoadTyped_RW(rw, 1, ext);
-            SDL_UnlockMutex(_pg_img_mutex);
-        }
-        else {
-            surf = IMG_LoadTyped_RW(rw, 1, ext);
-        }
-        Py_END_ALLOW_THREADS;
-#else /* ~WITH_THREAD */
         surf = IMG_LoadTyped_RW(rw, 1, ext);
+    }
+    Py_END_ALLOW_THREADS;
+#else  /* ~WITH_THREAD */
+    surf = IMG_LoadTyped_RW(rw, 1, ext);
 #endif /* ~WITH_THREAD */
-        PyMem_Free(ext);
-    }
 
-    if (surf == NULL) {
+    if (surf == NULL)
         return RAISE(pgExc_SDLError, IMG_GetError());
-    }
-    final = pgSurface_New(surf);
+
+    final = (PyObject *)pgSurface_New(surf);
     if (final == NULL) {
         SDL_FreeSurface(surf);
     }
@@ -216,27 +155,37 @@ png_write_fn(png_structp png_ptr, png_bytep data, png_size_t length)
     SDL_RWops *rwops = (SDL_RWops *)png_get_io_ptr(png_ptr);
     if (SDL_RWwrite(rwops, data, 1, length) != length) {
         SDL_RWclose(rwops);
-        png_error(png_ptr, "Error while writing to the PNG file (SDL_RWwrite)");
+        png_error(png_ptr,
+                  "Error while writing to the PNG file (SDL_RWwrite)");
     }
 }
 
 static void
 png_flush_fn(png_structp png_ptr)
 {
-    /* TODO: add SDL_RWflush() when it exists */
+    SDL_RWops *rwops = (SDL_RWops *)png_get_io_ptr(png_ptr);
+    if (pg_RWflush(rwops)) {
+        SDL_RWclose(rwops);
+        png_error(png_ptr, "Error while writing to PNG file (flush)");
+    }
 }
 
 static int
-write_png(const char *file_name, png_bytep *rows, int w, int h, int colortype,
-          int bitdepth)
+write_png(const char *file_name, SDL_RWops *rw, png_bytep *rows, int w, int h,
+          int colortype, int bitdepth)
 {
     png_structp png_ptr = NULL;
     png_infop info_ptr = NULL;
     SDL_RWops *rwops;
     char *doing;
 
-    if (!(rwops = SDL_RWFromFile(file_name, "wb"))) {
-        return -1;
+    if (rw == NULL) {
+        if (!(rwops = SDL_RWFromFile(file_name, "wb"))) {
+            return -1;
+        }
+    }
+    else {
+        rwops = rw;
     }
 
     doing = "create png write struct";
@@ -267,9 +216,11 @@ write_png(const char *file_name, png_bytep *rows, int w, int h, int colortype,
     doing = "write end";
     png_write_end(png_ptr, NULL);
 
-    doing = "closing file";
-    if (0 != SDL_RWclose(rwops))
-        goto fail;
+    if (rw == NULL) {
+        doing = "closing file";
+        if (0 != SDL_RWclose(rwops))
+            goto fail;
+    }
     png_destroy_write_struct(&png_ptr, &info_ptr);
     return 0;
 
@@ -289,7 +240,7 @@ fail:
 }
 
 static int
-SavePNG(SDL_Surface *surface, const char *file)
+SavePNG(SDL_Surface *surface, const char *file, SDL_RWops *rw)
 {
     static unsigned char **ss_rows;
     static int ss_size;
@@ -299,16 +250,10 @@ SavePNG(SDL_Surface *surface, const char *file)
     int r, i;
     int alpha = 0;
 
-#if IS_SDLv1
-    unsigned surf_flags;
-    unsigned surf_alpha;
-    unsigned surf_colorkey;
-#else  /* IS_SDLv2 */
     Uint8 surf_alpha = 255;
     Uint32 surf_colorkey;
     int has_colorkey = 0;
     SDL_BlendMode surf_mode;
-#endif /* IS_SDLv2 */
 
     ss_rows = 0;
     ss_size = 0;
@@ -317,28 +262,6 @@ SavePNG(SDL_Surface *surface, const char *file)
     ss_w = surface->w;
     ss_h = surface->h;
 
-#if IS_SDLv1
-    if (surface->format->Amask) {
-        alpha = 1;
-        ss_surface =
-            SDL_CreateRGBSurface(SDL_SWSURFACE | SDL_SRCALPHA, ss_w, ss_h, 32,
-#if SDL_BYTEORDER == SDL_BIG_ENDIAN
-                                 0xff000000, 0xff0000, 0xff00, 0xff
-#else
-                                 0xff, 0xff00, 0xff0000, 0xff000000
-#endif
-            );
-    }
-    else {
-        ss_surface = SDL_CreateRGBSurface(SDL_SWSURFACE, ss_w, ss_h, 24,
-#if SDL_BYTEORDER == SDL_BIG_ENDIAN
-                                          0xff0000, 0xff00, 0xff, 0
-#else
-                                          0xff, 0xff00, 0xff0000, 0
-#endif
-        );
-    }
-#else /* IS_SDLv2 */
     if (surface->format->Amask) {
         alpha = 1;
         ss_surface = SDL_CreateRGBSurface(0, ss_w, ss_h, 32,
@@ -358,21 +281,10 @@ SavePNG(SDL_Surface *surface, const char *file)
 #endif
         );
     }
-#endif /* IS_SDLv2 */
 
     if (ss_surface == NULL)
         return -1;
 
-#if IS_SDLv1
-    surf_flags = surface->flags & (SDL_SRCALPHA | SDL_SRCCOLORKEY);
-    surf_alpha = surface->format->alpha;
-    surf_colorkey = surface->format->colorkey;
-
-    if (surf_flags & SDL_SRCALPHA)
-        SDL_SetAlpha(surface, 0, 255);
-    if (surf_flags & SDL_SRCCOLORKEY)
-        SDL_SetColorKey(surface, 0, surface->format->colorkey);
-#else /* IS_SDLv2 */
     SDL_GetSurfaceAlphaMod(surface, &surf_alpha);
     SDL_SetSurfaceAlphaMod(surface, 255);
     SDL_GetSurfaceBlendMode(surface, &surf_mode);
@@ -382,7 +294,6 @@ SavePNG(SDL_Surface *surface, const char *file)
         has_colorkey = 1;
         SDL_SetColorKey(surface, SDL_FALSE, surf_colorkey);
     }
-#endif /* IS_SDLv2 */
 
     ss_rect.x = 0;
     ss_rect.y = 0;
@@ -396,17 +307,10 @@ SavePNG(SDL_Surface *surface, const char *file)
         if (ss_rows == NULL)
             return -1;
     }
-#if IS_SDLv1
-    if (surf_flags & SDL_SRCALPHA)
-        SDL_SetAlpha(surface, SDL_SRCALPHA, (Uint8)surf_alpha);
-    if (surf_flags & SDL_SRCCOLORKEY)
-        SDL_SetColorKey(surface, SDL_SRCCOLORKEY, surf_colorkey);
-#else  /* IS_SDLv2 */
     if (has_colorkey)
         SDL_SetColorKey(surface, SDL_TRUE, surf_colorkey);
     SDL_SetSurfaceAlphaMod(surface, surf_alpha);
     SDL_SetSurfaceBlendMode(surface, surf_mode);
-#endif /* IS_SDLv2 */
 
     for (i = 0; i < ss_h; i++) {
         ss_rows[i] =
@@ -414,11 +318,11 @@ SavePNG(SDL_Surface *surface, const char *file)
     }
 
     if (alpha) {
-        r = write_png(file, ss_rows, surface->w, surface->h,
+        r = write_png(file, rw, ss_rows, surface->w, surface->h,
                       PNG_COLOR_TYPE_RGB_ALPHA, 8);
     }
     else {
-        r = write_png(file, ss_rows, surface->w, surface->h,
+        r = write_png(file, rw, ss_rows, surface->w, surface->h,
                       PNG_COLOR_TYPE_RGB, 8);
     }
 
@@ -444,8 +348,8 @@ SavePNG(SDL_Surface *surface, const char *file)
 typedef struct {
     struct jpeg_destination_mgr pub; /* public fields */
 
-    SDL_RWops *outfile;  /* target stream */
-    JOCTET *buffer; /* start of buffer */
+    SDL_RWops *outfile; /* target stream */
+    JOCTET *buffer;     /* start of buffer */
 } j_outfile_mgr;
 
 static void
@@ -485,11 +389,14 @@ j_term_destination(j_compress_ptr cinfo)
 
     /* Write any data remaining in the buffer */
     if (datacount > 0) {
-        if (SDL_RWwrite(dest->outfile, dest->buffer, 1, datacount) != datacount) {
+        if (SDL_RWwrite(dest->outfile, dest->buffer, 1, datacount) !=
+            datacount) {
             ERREXIT(cinfo, JERR_FILE_WRITE);
         }
     }
-    /* TODO: add SDL_RWflush() when it exists */
+    if (pg_RWflush(dest->outfile)) {
+        ERREXIT(cinfo, JERR_FILE_WRITE);
+    }
 }
 
 static void
@@ -527,8 +434,7 @@ write_jpeg(const char *file_name, unsigned char **image_buffer,
     struct jpeg_error_mgr jerr;
     SDL_RWops *outfile;
     JSAMPROW row_pointer[NUM_LINES_TO_WRITE];
-    int num_lines_to_write;
-    int i;
+    JDIMENSION i, num_lines_to_write;
 
     num_lines_to_write = NUM_LINES_TO_WRITE;
 
@@ -596,6 +502,10 @@ SaveJPEG(SDL_Surface *surface, const char *file)
     int pixel_bits = 32;
     int free_ss_surface = 1;
 
+    if (!surface) {
+        return -1;
+    }
+
     ss_rows = 0;
     ss_size = 0;
     ss_surface = NULL;
@@ -605,26 +515,10 @@ SaveJPEG(SDL_Surface *surface, const char *file)
 
     pixel_bits = 24;
 
-    if (!surface) {
-        return -1;
-    }
-
     /* See if the Surface is suitable for using directly.
        So no conversion is needed.  24bit, RGB
     */
 
-#if IS_SDLv1
-    if ((surface->format->BytesPerPixel == 3) &&
-        !(surface->flags & SDL_SRCALPHA) &&
-        (surface->format->Rmask == RED_MASK)) {
-        /*
-           printf("not creating...\n");
-        */
-        ss_surface = surface;
-
-        free_ss_surface = 0;
-    }
-#else  /* IS_SDLv2 */
     if (surface->format->format == SDL_PIXELFORMAT_RGB24) {
         /*
            printf("not creating...\n");
@@ -633,7 +527,6 @@ SaveJPEG(SDL_Surface *surface, const char *file)
 
         free_ss_surface = 0;
     }
-#endif /* IS_SDLv2 */
     else {
         /*
         printf("creating...\n");
@@ -642,14 +535,8 @@ SaveJPEG(SDL_Surface *surface, const char *file)
         /* If it is not, then we need to make a new surface.
          */
 
-#if IS_SDLv1
-        ss_surface =
-            SDL_CreateRGBSurface(SDL_SWSURFACE, ss_w, ss_h, pixel_bits,
-                                 RED_MASK, GREEN_MASK, BLUE_MASK, 0);
-#else  /* IS_SDLv2 */
         ss_surface = SDL_CreateRGBSurface(0, ss_w, ss_h, pixel_bits, RED_MASK,
                                           GREEN_MASK, BLUE_MASK, 0);
-#endif /* IS_SDLv2 */
         if (ss_surface == NULL) {
             return -1;
         }
@@ -692,163 +579,117 @@ SaveJPEG(SDL_Surface *surface, const char *file)
 
 #endif /* end if JPEGLIB_H */
 
-#if IS_SDLv1
-/* NOTE XX HACK TODO FIXME: this opengltosdl is also in image.c
-   need to share it between both.
-*/
-
-static SDL_Surface *
-opengltosdl(void)
-{
-    /*we need to get ahold of the pyopengl glReadPixels function*/
-    /*we use pyopengl's so we don't need to link with opengl at compiletime*/
-    SDL_Surface *surf = NULL;
-    Uint32 rmask, gmask, bmask;
-    int i;
-    unsigned char *pixels = NULL;
-
-    GL_glReadPixels_Func p_glReadPixels = NULL;
-
-    p_glReadPixels =
-        (GL_glReadPixels_Func)SDL_GL_GetProcAddress("glReadPixels");
-
-    surf = SDL_GetVideoSurface();
-
-    if (!surf) {
-        RAISE(PyExc_RuntimeError, "Cannot get video surface.");
-        return NULL;
-    }
-    if (!p_glReadPixels) {
-        RAISE(PyExc_RuntimeError, "Cannot find glReadPixels function.");
-        return NULL;
-    }
-
-    pixels = (unsigned char *)malloc(surf->w * surf->h * 3);
-
-    if (!pixels) {
-        RAISE(PyExc_MemoryError, "Cannot allocate enough memory for pixels.");
-        return NULL;
-    }
-
-    /* GL_RGB, GL_UNSIGNED_BYTE */
-    p_glReadPixels(0, 0, surf->w, surf->h, 0x1907, 0x1401, pixels);
-
-    if (SDL_BYTEORDER == SDL_LIL_ENDIAN) {
-        rmask = 0x000000FF;
-        gmask = 0x0000FF00;
-        bmask = 0x00FF0000;
-    }
-    else {
-        rmask = 0x00FF0000;
-        gmask = 0x0000FF00;
-        bmask = 0x000000FF;
-    }
-    surf = SDL_CreateRGBSurface(SDL_SWSURFACE, surf->w, surf->h, 24, rmask,
-                                gmask, bmask, 0);
-    if (!surf) {
-        free(pixels);
-        RAISE(pgExc_SDLError, SDL_GetError());
-        return NULL;
-    }
-
-    for (i = 0; i < surf->h; ++i) {
-        memcpy(((char *)surf->pixels) + surf->pitch * i,
-               pixels + 3 * surf->w * (surf->h - i - 1), surf->w * 3);
-    }
-
-    free(pixels);
-    return surf;
-}
-
-#endif /* IS_SDLv1 */
-
 static PyObject *
 image_save_ext(PyObject *self, PyObject *arg)
 {
-    PyObject *surfobj;
+    pgSurfaceObject *surfobj;
     PyObject *obj;
+    const char *namehint = NULL;
     PyObject *oencoded = NULL;
     SDL_Surface *surf;
-    SDL_Surface *temp = NULL;
     int result = 1;
+    const char *name = NULL;
+    SDL_RWops *rw = NULL;
 
-    if (!PyArg_ParseTuple(arg, "O!O", &pgSurface_Type, &surfobj, &obj)) {
+    if (!PyArg_ParseTuple(arg, "O!O|s", &pgSurface_Type, &surfobj, &obj,
+                          &namehint)) {
         return NULL;
     }
 
     surf = pgSurface_AsSurface(surfobj);
-#if IS_SDLv1
-    if (surf->flags & SDL_OPENGL) {
-        temp = surf = opengltosdl();
-        if (surf == NULL) {
-            return NULL;
+    pgSurface_Prep(surfobj);
+
+    oencoded = pg_EncodeString(obj, "UTF-8", NULL, pgExc_SDLError);
+    if (oencoded == NULL) {
+        result = -2;
+    }
+    else if (oencoded == Py_None) {
+        rw = pgRWops_FromFileObject(obj);
+        if (rw == NULL) {
+            PyErr_Format(PyExc_TypeError,
+                         "Expected a string or file object for the file "
+                         "argument: got %.1024s",
+                         Py_TYPE(obj)->tp_name);
+            result = -2;
+        }
+        else {
+            name = namehint;
         }
     }
     else {
-        pgSurface_Prep(surfobj);
+        name = PyBytes_AS_STRING(oencoded);
     }
-#else  /* IS_SDLv2 */
-    pgSurface_Prep(surfobj);
-#endif /* IS_SDLv2 */
 
-    oencoded = pg_EncodeString(obj, "UTF-8", NULL, pgExc_SDLError);
-    if (oencoded == Py_None) {
-        PyErr_Format(PyExc_TypeError,
-                     "Expected a string for the file argument: got %.1024s",
-                     Py_TYPE(obj)->tp_name);
-        result = -2;
-    }
-    else if (oencoded != NULL) {
-        const char *name = Bytes_AS_STRING(oencoded);
-        Py_ssize_t namelen = Bytes_GET_SIZE(oencoded);
-
-        if ((namelen >= 4) &&
-            (((name[namelen - 1] == 'g' || name[namelen - 1] == 'G') &&
-              (name[namelen - 2] == 'e' || name[namelen - 2] == 'E') &&
-              (name[namelen - 3] == 'p' || name[namelen - 3] == 'P') &&
-              (name[namelen - 4] == 'j' || name[namelen - 4] == 'J')) ||
-             ((name[namelen - 1] == 'g' || name[namelen - 1] == 'G') &&
-              (name[namelen - 2] == 'p' || name[namelen - 2] == 'P') &&
-              (name[namelen - 3] == 'j' || name[namelen - 3] == 'J')))) {
-#ifdef JPEGLIB_H
-            /* jpg save functions seem *NOT* thread safe at least on windows.
+    if (result > 0) {
+        const char *ext = find_extension(name);
+        if (!strcasecmp(ext, "jpeg") || !strcasecmp(ext, "jpg")) {
+#if (SDL_IMAGE_MAJOR_VERSION * 1000 + SDL_IMAGE_MINOR_VERSION * 100 + \
+     SDL_IMAGE_PATCHLEVEL) < 2002
+            /* SDL_Image is a version less than 2.0.2 and therefore does not
+             * have the functions IMG_SaveJPG() and IMG_SaveJPG_RW().
              */
-            /*
-            Py_BEGIN_ALLOW_THREADS;
-            */
-            result = SaveJPEG(surf, name);
-            /*
-            Py_END_ALLOW_THREADS;
-            */
+            if (rw != NULL) {
+                PyErr_SetString(pgExc_SDLError,
+                                "SDL_Image 2.0.2 or newer needed to save "
+                                "jpeg to a fileobject.");
+                result = -2;
+            }
+            else {
+#ifdef JPEGLIB_H
+                /* jpg save functions seem *NOT* thread safe at least on
+                 * windows.
+                 */
+                /*
+                Py_BEGIN_ALLOW_THREADS;
+                */
+                result = SaveJPEG(surf, name);
+                /*
+                Py_END_ALLOW_THREADS;
+                */
 #else
-            RAISE(pgExc_SDLError, "No support for jpg compiled in.");
-            result = -2;
+                PyErr_SetString(pgExc_SDLError,
+                                "No support for jpg compiled in.");
+                result = -2;
 #endif /* ~JPEGLIB_H */
+            }
+#else
+            /* SDL_Image is version 2.0.2 or newer and therefore does
+             * have the functions IMG_SaveJPG() and IMG_SaveJPG_RW().
+             */
+            if (rw != NULL) {
+                result = IMG_SaveJPG_RW(surf, rw, 0, JPEG_QUALITY);
+            }
+            else {
+                result = IMG_SaveJPG(surf, name, JPEG_QUALITY);
+#ifdef JPEGLIB_H
+                /* In the unlikely event that pygame is compiled with support
+                 * for jpg but SDL_Image was not, then we can catch that and
+                 * try calling the pygame SaveJPEG function.
+                 */
+                if (result == -1) {
+                    if (strstr(SDL_GetError(), "not built with jpeglib") !=
+                        NULL) {
+                        SDL_ClearError();
+                        result = SaveJPEG(surf, name);
+                    }
+                }
+#endif /* JPEGLIB_H */
+            }
+#endif /* SDL_Image >= 2.0.2 */
         }
-        else if ((namelen >= 3) &&
-                 ((name[namelen - 1] == 'g' || name[namelen - 1] == 'G') &&
-                  (name[namelen - 2] == 'n' || name[namelen - 2] == 'N') &&
-                  (name[namelen - 3] == 'p' || name[namelen - 3] == 'P'))) {
+        else if (!strcasecmp(ext, "png")) {
 #ifdef PNG_H
             /*Py_BEGIN_ALLOW_THREADS; */
-            result = SavePNG(surf, name);
+            result = SavePNG(surf, name, rw);
             /*Py_END_ALLOW_THREADS; */
 #else
-            RAISE(pgExc_SDLError, "No support for png compiled in.");
+            PyErr_SetString(pgExc_SDLError, "No support for png compiled in.");
             result = -2;
 #endif /* ~PNG_H */
         }
     }
-    else {
-        result = -2;
-    }
 
-    if (temp != NULL) {
-        SDL_FreeSurface(temp);
-    }
-    else {
-        pgSurface_Unprep(surfobj);
-    }
+    pgSurface_Unprep(surfobj);
 
     Py_XDECREF(oencoded);
     if (result == -2) {
@@ -866,8 +707,14 @@ image_save_ext(PyObject *self, PyObject *arg)
     Py_RETURN_NONE;
 }
 
+static PyObject *
+image_get_sdl_image_version(PyObject *self, PyObject *arg)
+{
+    return Py_BuildValue("iii", SDL_IMAGE_MAJOR_VERSION,
+                         SDL_IMAGE_MINOR_VERSION, SDL_IMAGE_PATCHLEVEL);
+}
+
 #ifdef WITH_THREAD
-#if PY3
 static void
 _imageext_free(void *ptr)
 {
@@ -876,21 +723,14 @@ _imageext_free(void *ptr)
         _pg_img_mutex = 0;
     }
 }
-#else /* PY2 */
-static void
-_imageext_free(void)
-{
-    if (_pg_img_mutex) {
-        SDL_DestroyMutex(_pg_img_mutex);
-        _pg_img_mutex = 0;
-    }
-}
-#endif /* PY2 */
 #endif /* WITH_THREAD */
 
 static PyMethodDef _imageext_methods[] = {
     {"load_extended", image_load_ext, METH_VARARGS, DOC_PYGAMEIMAGE},
     {"save_extended", image_save_ext, METH_VARARGS, DOC_PYGAMEIMAGE},
+    {"_get_sdl_image_version", image_get_sdl_image_version, METH_NOARGS,
+     "_get_sdl_image_version() -> (major, minor, patch)\n"
+     "Note: Should not be used directly."},
     {NULL, NULL, 0, NULL}};
 
 /*DOC*/ static char _imageext_doc[] =
@@ -898,56 +738,40 @@ static PyMethodDef _imageext_methods[] = {
 
 MODINIT_DEFINE(imageext)
 {
-#if PY3
-    static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
-                                         "imageext",
-                                         _imageext_doc,
-                                         -1,
-                                         _imageext_methods,
-                                         NULL,
-                                         NULL,
-                                         NULL,
+    static struct PyModuleDef _module = {
+        PyModuleDef_HEAD_INIT, "imageext", _imageext_doc, -1,
+        _imageext_methods,     NULL,       NULL,          NULL,
 #ifdef WITH_THREAD
-                                         _imageext_free};
-#else /* ~WITH_THREAD */
+        _imageext_free};
+#else  /* ~WITH_THREAD */
                                          0};
 #endif /* ~WITH_THREAD */
-#endif
 
     /* imported needed apis; Do this first so if there is an error
        the module is not loaded.
     */
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
     import_pygame_surface();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
     import_pygame_rwobject();
 
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
 #ifdef WITH_THREAD
-#if PY2
-    if (Py_AtExit(_imageext_free)) {
-        MODINIT_ERROR;
-    }
-#endif /* PY2 */
     _pg_img_mutex = SDL_CreateMutex();
     if (!_pg_img_mutex) {
         PyErr_SetString(pgExc_SDLError, SDL_GetError());
-        MODINIT_ERROR;
+        return NULL;
     }
 #endif /* WITH_THREAD */
 
     /* create the module */
-#if PY3
     return PyModule_Create(&_module);
-#else
-    Py_InitModule3(MODPREFIX "imageext", _imageext_methods, _imageext_doc);
-#endif
 }
