@@ -23,19 +23,13 @@
 #include <stddef.h>
 #include "pygame.h"
 
-#if IS_SDLv2
 #include "palette.h"
-#endif /* IS_SDLv2 */
 
 #include "pgcompat.h"
 
 #include "doc/pixelcopy_doc.h"
 
-#if IS_SDLv1
-#include <SDL_byteorder.h>
-#else /* IS_SDLv2 */
 #include <SDL_endian.h>
-#endif /* IS_SDLv2 */
 
 typedef enum {
     VIEWKIND_RED,
@@ -134,20 +128,20 @@ _view_kind(PyObject *obj, void *view_kind_vptr)
     _pc_view_kind_t *view_kind_ptr = (_pc_view_kind_t *)view_kind_vptr;
 
     if (PyUnicode_Check(obj)) {
-        if (PyUnicode_GET_SIZE(obj) != 1) {
+        if (PyUnicode_GET_LENGTH(obj) != 1) {
             PyErr_SetString(PyExc_TypeError,
                             "expected a length 1 string for argument 3");
             return 0;
         }
-        ch = *PyUnicode_AS_UNICODE(obj);
+        ch = PyUnicode_READ_CHAR(obj, 0);
     }
-    else if (Bytes_Check(obj)) {
-        if (Bytes_GET_SIZE(obj) != 1) {
+    else if (PyBytes_Check(obj)) {
+        if (PyBytes_GET_SIZE(obj) != 1) {
             PyErr_SetString(PyExc_TypeError,
                             "expected a length 1 string for argument 3");
             return 0;
         }
-        ch = *Bytes_AS_STRING(obj);
+        ch = *PyBytes_AS_STRING(obj);
     }
     else {
         PyErr_Format(PyExc_TypeError,
@@ -259,11 +253,7 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
 {
     SDL_PixelFormat *format = surf->format;
     int pixelsize = surf->format->BytesPerPixel;
-#if IS_SDLv1
-    Uint32 flags = surf->flags;
-#else /* IS_SDLv2 */
     SDL_BlendMode mode;
-#endif /* IS_SDLv2 */
     int intsize = (int)view_p->itemsize;
     char *src = (char *)surf->pixels;
     char *dst = (char *)view_p->buf;
@@ -293,12 +283,10 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
                      intsize);
         return -1;
     }
-#if IS_SDLv2
     if (SDL_GetSurfaceBlendMode(surf, &mode) < 0) {
         PyErr_SetString(pgExc_SDLError, SDL_GetError());
         return -1;
     }
-#endif
     /* Select appropriate color plane element within the pixel */
     switch (view_kind) {
         case VIEWKIND_RED:
@@ -329,13 +317,8 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
         dz_dst = -1;
     }
 #endif
-#if IS_SDLv1
-    if (view_kind == VIEWKIND_COLORKEY && flags & SDL_SRCCOLORKEY) {
-        colorkey = format->colorkey;
-#else  /* IS_SDLv2 */
     if (view_kind == VIEWKIND_COLORKEY &&
         SDL_GetColorKey(surf, &colorkey) == 0) {
-#endif /* IS_SDLv2 */
         for (x = 0; x < w; ++x) {
             for (y = 0; y < h; ++y) {
                 for (z = 0; z < pixelsize; ++z) {
@@ -349,13 +332,8 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
             }
         }
     }
-#if IS_SDLv1
-    else if ((view_kind != VIEWKIND_COLORKEY) &&
-             (view_kind != VIEWKIND_ALPHA || flags & SDL_SRCALPHA)) {
-#else  /* IS_SDLv2 */
     else if ((view_kind != VIEWKIND_COLORKEY) &&
              (view_kind != VIEWKIND_ALPHA || mode != SDL_BLENDMODE_NONE)) {
-#endif /* IS_SDLv2 */
         for (x = 0; x < w; ++x) {
             for (y = 0; y < h; ++y) {
                 for (z = 0; z < pixelsize; ++z) {
@@ -480,7 +458,8 @@ _copy_unmapped(Py_buffer *view_p, SDL_Surface *surf)
 static PyObject *
 array_to_surface(PyObject *self, PyObject *arg)
 {
-    PyObject *surfobj, *arrayobj;
+    pgSurfaceObject *surfobj;
+    PyObject *arrayobj;
     pg_buffer pg_view;
     Py_buffer *view_p = (Py_buffer *)&pg_view;
     char *array_data;
@@ -508,7 +487,7 @@ array_to_surface(PyObject *self, PyObject *arg)
         return RAISE(PyExc_ValueError, "must be a valid 2d or 3d array\n");
     }
 
-    if (surf->format->BytesPerPixel <= 0 || surf->format->BytesPerPixel > 4)
+    if (surf->format->BytesPerPixel == 0 || surf->format->BytesPerPixel > 4)
         return RAISE(PyExc_ValueError, "unsupport bit depth for surface");
 
     stridex = view_p->strides[0];
@@ -774,7 +753,7 @@ static PyObject *
 surface_to_array(PyObject *self, PyObject *args, PyObject *kwds)
 {
     PyObject *arrayobj;
-    PyObject *surfobj;
+    pgSurfaceObject *surfobj;
     pg_buffer pg_view;
     Py_buffer *view_p = (Py_buffer *)&pg_view;
     _pc_view_kind_t view_kind = VIEWKIND_RGB;
@@ -854,7 +833,7 @@ map_array(PyObject *self, PyObject *args)
 #define PIXELCOPY_MAX_DIM 10
     PyObject *src_array;
     PyObject *tar_array;
-    PyObject *format_surf;
+    pgSurfaceObject *format_surf;
     SDL_PixelFormat *format;
     pg_buffer src_pg_view;
     Py_buffer *src_view_p = 0;
@@ -935,7 +914,7 @@ map_array(PyObject *self, PyObject *args)
     }
     if (src_view_p->shape[src_ndim - 1] != 3) {
         PyErr_Format(PyExc_ValueError,
-                     "Expected a (..., 3) source array: got (..., %d)",
+                     "Expected a (..., 3) source array: got (..., %zd)",
                      src_view_p->shape[src_ndim - 1]);
         goto fail;
     }
@@ -972,7 +951,7 @@ map_array(PyObject *self, PyObject *args)
             src_strides[dim] - shape[dim + 1] * src_strides[dim + 1];
     }
 
-    /* Determine souce and destination pixel formats
+    /* Determine source and destination pixel formats
      */
     format = pgSurface_AsSurface(format_surf)->format;
     pix_bytesize = format->BytesPerPixel;
@@ -1141,7 +1120,7 @@ make_surface(PyObject *self, PyObject *arg)
 {
     pg_buffer pg_view;
     Py_buffer *view_p = (Py_buffer *)&pg_view;
-    PyObject *surfobj;
+    pgSurfaceObject *surfobj;
     PyObject *args;
     PyObject *result;
     SDL_Surface *surf;
@@ -1163,15 +1142,9 @@ make_surface(PyObject *self, PyObject *arg)
 
     if (view_p->ndim == 2) {
         bitsperpixel = 8;
-#if IS_SDLv1
-        rmask = 0xFF >> 6 << 5;
-        gmask = 0xFF >> 5 << 2;
-        bmask = 0xFF >> 6;
-#else  /* IS_SDLv2 */
         rmask = 0;
         gmask = 0;
         bmask = 0;
-#endif /* IS_SDLv2 */
     }
     else {
         bitsperpixel = 32;
@@ -1188,7 +1161,6 @@ make_surface(PyObject *self, PyObject *arg)
         pgBuffer_Release(&pg_view);
         return RAISE(pgExc_SDLError, SDL_GetError());
     }
-#if IS_SDLv2
     if (SDL_ISPIXELFORMAT_INDEXED(surf->format->format)) {
         /* Give the surface something other than an all white palette.
          *          */
@@ -1199,7 +1171,6 @@ make_surface(PyObject *self, PyObject *arg)
             return 0;
         }
     }
-#endif /* IS_SDLv2 */
     surfobj = pgSurface_New(surf);
     if (!surfobj) {
         pgBuffer_Release(&pg_view);
@@ -1223,7 +1194,7 @@ make_surface(PyObject *self, PyObject *arg)
         return 0;
     }
     Py_DECREF(result);
-    return surfobj;
+    return (PyObject *)surfobj;
 }
 
 static PyMethodDef _pixelcopy_methods[] = {
@@ -1237,7 +1208,6 @@ static PyMethodDef _pixelcopy_methods[] = {
 
 MODINIT_DEFINE(pixelcopy)
 {
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          "pixelcopy",
                                          DOC_PYGAMEPIXELCOPY,
@@ -1247,23 +1217,18 @@ MODINIT_DEFINE(pixelcopy)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     /* imported needed apis; Do this first so if there is an error
        the module is not loaded.
     */
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
     import_pygame_surface();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
-#if PY3
     return PyModule_Create(&_module);
-#else
-    Py_InitModule3("pixelcopy", _pixelcopy_methods, DOC_PYGAMEPIXELCOPY);
-#endif
 }
