@@ -45,7 +45,7 @@ zoomSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst, int smooth)
         sstep;
     tColorRGBA *c00, *c01, *c10, *c11;
     tColorRGBA *sp, *csp, *dp;
-    int sgap, dgap;
+    int dgap;
 
     /*
      * Variable setup
@@ -99,9 +99,8 @@ zoomSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst, int smooth)
     /*
      * Pointer setup
      */
-    sp = csp = (tColorRGBA *)src->pixels;
+    csp = (tColorRGBA *)src->pixels;
     dp = (tColorRGBA *)dst->pixels;
-    sgap = src->pitch - src->w * 4;
     dgap = dst->pitch - dst->w * 4;
 
     /*
@@ -220,7 +219,7 @@ zoomSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst, int smooth)
 
  32bit Rotozoomer with optional anti-aliasing by bilinear interpolation.
 
- Rotates and zoomes 32bit RGBA/ABGR 'src' surface to 'dst' surface.
+ Rotates and zooms 32bit RGBA/ABGR 'src' surface to 'dst' surface.
 
 */
 
@@ -288,7 +287,6 @@ transformSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst, int cx, int cy,
                         c11 = *sp;
                     }
                     else if ((dx == -1) && (dy == sh)) {
-                        sp = (tColorRGBA *)(src->pixels);
                         sp = (tColorRGBA *)((Uint8 *)src->pixels +
                                             src->pitch * dy);
                         c00 = *sp;
@@ -405,7 +403,7 @@ transformSurfaceRGBA(SDL_Surface *src, SDL_Surface *dst, int cx, int cy,
 
  rotozoomSurface()
 
- Rotates and zoomes a 32bit or 8bit 'src' surface to newly created 'dst'
+ Rotates and zooms a 32bit or 8bit 'src' surface to newly created 'dst'
  surface. 'angle' is the rotation in degrees. 'zoom' a scaling factor. If
  'smooth' is 1 then the destination 32bit surface is anti-aliased. If the
  surface is not 8bit or 32bit RGBA/ABGR it will be converted into a 32bit RGBA
@@ -452,7 +450,7 @@ rotozoomSurfaceSizeTrig(int width, int height, double angle, double zoom,
     *dstheight = 2 * dstheighthalf;
 }
 
-/* Publically available rotozoom-size function */
+/* Publicly available rotozoom-size function */
 
 void
 rotozoomSurfaceSize(int width, int height, double angle, double zoom,
@@ -502,7 +500,7 @@ zoomSurfaceSize(int width, int height, double zoomx, double zoomy,
     }
 }
 
-/* Publically available rotozoom function */
+/* Publicly available rotozoom function */
 
 SDL_Surface *
 rotozoomSurface(SDL_Surface *src, double angle, double zoom, int smooth)
@@ -510,8 +508,7 @@ rotozoomSurface(SDL_Surface *src, double angle, double zoom, int smooth)
     SDL_Surface *rz_src;
     SDL_Surface *rz_dst;
     double zoominv;
-    double sanglezoom, canglezoom, sanglezoominv, canglezoominv;
-    int dstwidthhalf, dstwidth, dstheighthalf, dstheight;
+    int dstwidth, dstheight;
     int is32bit;
     int src_converted;
 
@@ -541,7 +538,6 @@ rotozoomSurface(SDL_Surface *src, double angle, double zoom, int smooth)
                                  0x0000ff00, 0x00ff0000, 0xff000000);
         SDL_BlitSurface(src, NULL, rz_src, NULL);
         src_converted = 1;
-        is32bit = 1;
     }
 
     /*
@@ -562,6 +558,8 @@ rotozoomSurface(SDL_Surface *src, double angle, double zoom, int smooth)
         /*
          * -----------------------
          */
+        int dstwidthhalf, dstheighthalf;
+        double sanglezoom, canglezoom, sanglezoominv, canglezoominv;
 
         /* Determine target size */
         rotozoomSurfaceSizeTrig(rz_src->w, rz_src->h, angle, zoom, &dstwidth,
@@ -608,11 +606,7 @@ rotozoomSurface(SDL_Surface *src, double angle, double zoom, int smooth)
         /*
          * Turn on source-alpha support
          */
-#if IS_SDLv1
-        SDL_SetAlpha(rz_dst, SDL_SRCALPHA, 255);
-#else  /* IS_SDLv2 */
         SDL_SetSurfaceAlphaMod(rz_dst, SDL_ALPHA_OPAQUE);
-#endif /* IS_SDLv2 */
         /*
          * Unlock source surface
          */
@@ -659,11 +653,7 @@ rotozoomSurface(SDL_Surface *src, double angle, double zoom, int smooth)
         /*
          * Turn on source-alpha support
          */
-#if IS_SDLv1
-        SDL_SetAlpha(rz_dst, SDL_SRCALPHA, 255);
-#else  /* IS_SDLv2 */
         SDL_SetSurfaceAlphaMod(rz_dst, SDL_ALPHA_OPAQUE);
-#endif /* IS_SDLv2 */
         /*
          * Unlock source surface
          */
